import { API as ParentAPI } from '@scaleway/sdk-client';
import type { CreateProjectRequest, DeleteProjectRequest, GetProjectRequest, ListProjectsRequest, ListProjectsResponse, Project, UpdateProjectRequest } from './types.gen';
/**
 * Account API.
 *
 * This API allows you to manage your Scaleway Projects.
 */
export declare class API extends ParentAPI {
    /**
     * Create a new Project for an Organization. Deprecated in favor of Account
     * API v3. Generate a new Project for an Organization, specifying its
     * configuration including name and description.
     *
     * @deprecated
     * @param request - The request {@link CreateProjectRequest}
     * @returns A Promise of Project
     */
    createProject: (request?: Readonly<CreateProjectRequest>) => Promise<Project>;
    protected pageOfListProjects: (request?: Readonly<ListProjectsRequest>) => Promise<ListProjectsResponse>;
    /**
     * List all Projects of an Organization. Deprecated in favor of Account API
     * v3. List all Projects of an Organization. The response will include the
     * total number of Projects as well as their associated Organizations, names
     * and IDs. Other information include the creation and update date of the
     * Project.
     *
     * @deprecated
     * @param request - The request {@link ListProjectsRequest}
     * @returns A Promise of ListProjectsResponse
     */
    listProjects: (request?: Readonly<ListProjectsRequest>) => Promise<ListProjectsResponse> & {
        all: () => Promise<Project[]>;
        [Symbol.asyncIterator]: () => AsyncGenerator<Project[], void, void>;
    };
    /**
     * Get an existing Project. Deprecated in favor of Account API v3. Retrieve
     * information about an existing Project, specified by its Project ID. Its
     * full details, including ID, name and description, are returned in the
     * response object.
     *
     * @deprecated
     * @param request - The request {@link GetProjectRequest}
     * @returns A Promise of Project
     */
    getProject: (request?: Readonly<GetProjectRequest>) => Promise<Project>;
    /**
     * Delete an existing Project. Deprecated in favor of Account API v3. Delete
     * an existing Project, specified by its Project ID. The Project needs to be
     * empty (meaning there are no resources left in it) to be deleted
     * effectively. Note that deleting a Project is permanent, and cannot be
     * undone.
     *
     * @deprecated
     * @param request - The request {@link DeleteProjectRequest}
     */
    deleteProject: (request?: Readonly<DeleteProjectRequest>) => Promise<void>;
    /**
     * Update Project. Deprecated in favor of Account API v3. Update the
     * parameters of an existing Project, specified by its Project ID. These
     * parameters include the name and description.
     *
     * @deprecated
     * @param request - The request {@link UpdateProjectRequest}
     * @returns A Promise of Project
     */
    updateProject: (request?: Readonly<UpdateProjectRequest>) => Promise<Project>;
}
