"use strict";
Object.defineProperty(exports, Symbol.toStringTag, { value: "Module" });
const randomName = require("@scaleway/random-name");
require("../../../client/dist/internal/logger/index.cjs");
const json = require("../../../client/dist/helpers/json.cjs");
const marshalling = require("../../../client/dist/helpers/marshalling.cjs");
require("../../../client/dist/vendor/base64/index.cjs");
const unmarshalProject = (data) => {
  if (!json.isJSONObject(data)) {
    throw new TypeError(
      `Unmarshalling the type 'Project' failed as data isn't a dictionary.`
    );
  }
  return {
    createdAt: marshalling.unmarshalDate(data.created_at),
    description: data.description,
    id: data.id,
    name: data.name,
    organizationId: data.organization_id,
    updatedAt: marshalling.unmarshalDate(data.updated_at)
  };
};
const unmarshalListProjectsResponse = (data) => {
  if (!json.isJSONObject(data)) {
    throw new TypeError(
      `Unmarshalling the type 'ListProjectsResponse' failed as data isn't a dictionary.`
    );
  }
  return {
    projects: marshalling.unmarshalArrayOfObject(data.projects, unmarshalProject),
    totalCount: data.total_count
  };
};
const marshalCreateProjectRequest = (request, defaults) => ({
  description: request.description,
  name: request.name || randomName("proj"),
  organization_id: request.organizationId ?? defaults.defaultOrganizationId
});
const marshalUpdateProjectRequest = (request, defaults) => ({
  description: request.description,
  name: request.name
});
exports.marshalCreateProjectRequest = marshalCreateProjectRequest;
exports.marshalUpdateProjectRequest = marshalUpdateProjectRequest;
exports.unmarshalListProjectsResponse = unmarshalListProjectsResponse;
exports.unmarshalProject = unmarshalProject;
