import randomName from "@scaleway/random-name";
import "../../../client/dist/internal/logger/index.js";
import { isJSONObject } from "../../../client/dist/helpers/json.js";
import { unmarshalDate, unmarshalArrayOfObject, resolveOneOf } from "../../../client/dist/helpers/marshalling.js";
import "../../../client/dist/vendor/base64/index.js";
const unmarshalContract = (data) => {
  if (!isJSONObject(data)) {
    throw new TypeError(
      `Unmarshalling the type 'Contract' failed as data isn't a dictionary.`
    );
  }
  return {
    createdAt: unmarshalDate(data.created_at),
    id: data.id,
    name: data.name,
    type: data.type,
    updatedAt: unmarshalDate(data.updated_at),
    version: data.version
  };
};
const unmarshalContractSignature = (data) => {
  if (!isJSONObject(data)) {
    throw new TypeError(
      `Unmarshalling the type 'ContractSignature' failed as data isn't a dictionary.`
    );
  }
  return {
    contract: data.contract ? unmarshalContract(data.contract) : void 0,
    createdAt: unmarshalDate(data.created_at),
    expiresAt: unmarshalDate(data.expires_at),
    id: data.id,
    organizationId: data.organization_id,
    signedAt: unmarshalDate(data.signed_at)
  };
};
const unmarshalProject = (data) => {
  if (!isJSONObject(data)) {
    throw new TypeError(
      `Unmarshalling the type 'Project' failed as data isn't a dictionary.`
    );
  }
  return {
    createdAt: unmarshalDate(data.created_at),
    description: data.description,
    id: data.id,
    name: data.name,
    organizationId: data.organization_id,
    updatedAt: unmarshalDate(data.updated_at)
  };
};
const unmarshalCheckContractSignatureResponse = (data) => {
  if (!isJSONObject(data)) {
    throw new TypeError(
      `Unmarshalling the type 'CheckContractSignatureResponse' failed as data isn't a dictionary.`
    );
  }
  return {
    created: data.created,
    validated: data.validated
  };
};
const unmarshalListContractSignaturesResponse = (data) => {
  if (!isJSONObject(data)) {
    throw new TypeError(
      `Unmarshalling the type 'ListContractSignaturesResponse' failed as data isn't a dictionary.`
    );
  }
  return {
    contractSignatures: unmarshalArrayOfObject(
      data.contract_signatures,
      unmarshalContractSignature
    ),
    totalCount: data.total_count
  };
};
const unmarshalListProjectsResponse = (data) => {
  if (!isJSONObject(data)) {
    throw new TypeError(
      `Unmarshalling the type 'ListProjectsResponse' failed as data isn't a dictionary.`
    );
  }
  return {
    projects: unmarshalArrayOfObject(data.projects, unmarshalProject),
    totalCount: data.total_count
  };
};
const unmarshalQualificationAiMachine = (data) => {
  if (!isJSONObject(data)) {
    throw new TypeError(
      `Unmarshalling the type 'QualificationAiMachine' failed as data isn't a dictionary.`
    );
  }
  return {};
};
const unmarshalQualificationArchiveData = (data) => {
  if (!isJSONObject(data)) {
    throw new TypeError(
      `Unmarshalling the type 'QualificationArchiveData' failed as data isn't a dictionary.`
    );
  }
  return {};
};
const unmarshalQualificationContainer = (data) => {
  if (!isJSONObject(data)) {
    throw new TypeError(
      `Unmarshalling the type 'QualificationContainer' failed as data isn't a dictionary.`
    );
  }
  return {};
};
const unmarshalQualificationDeploySoftware = (data) => {
  if (!isJSONObject(data)) {
    throw new TypeError(
      `Unmarshalling the type 'QualificationDeploySoftware' failed as data isn't a dictionary.`
    );
  }
  return {};
};
const unmarshalQualificationHostApplication = (data) => {
  if (!isJSONObject(data)) {
    throw new TypeError(
      `Unmarshalling the type 'QualificationHostApplication' failed as data isn't a dictionary.`
    );
  }
  return {
    subUseCase: data.sub_use_case
  };
};
const unmarshalQualificationHostWebsite = (data) => {
  if (!isJSONObject(data)) {
    throw new TypeError(
      `Unmarshalling the type 'QualificationHostWebsite' failed as data isn't a dictionary.`
    );
  }
  return {
    subUseCase: data.sub_use_case
  };
};
const unmarshalQualificationOtherUseCase = (data) => {
  if (!isJSONObject(data)) {
    throw new TypeError(
      `Unmarshalling the type 'QualificationOtherUseCase' failed as data isn't a dictionary.`
    );
  }
  return {};
};
const unmarshalQualificationSetScalewayEnvironment = (data) => {
  if (!isJSONObject(data)) {
    throw new TypeError(
      `Unmarshalling the type 'QualificationSetScalewayEnvironment' failed as data isn't a dictionary.`
    );
  }
  return {};
};
const unmarshalQualificationShareData = (data) => {
  if (!isJSONObject(data)) {
    throw new TypeError(
      `Unmarshalling the type 'QualificationShareData' failed as data isn't a dictionary.`
    );
  }
  return {};
};
const unmarshalQualification = (data) => {
  if (!isJSONObject(data)) {
    throw new TypeError(
      `Unmarshalling the type 'Qualification' failed as data isn't a dictionary.`
    );
  }
  return {
    aiMachine: data.ai_machine ? unmarshalQualificationAiMachine(data.ai_machine) : void 0,
    architectureType: data.architecture_type,
    archiveData: data.archive_data ? unmarshalQualificationArchiveData(data.archive_data) : void 0,
    container: data.container ? unmarshalQualificationContainer(data.container) : void 0,
    deploySoftware: data.deploy_software ? unmarshalQualificationDeploySoftware(data.deploy_software) : void 0,
    hostApplication: data.host_application ? unmarshalQualificationHostApplication(data.host_application) : void 0,
    hostWebsite: data.host_website ? unmarshalQualificationHostWebsite(data.host_website) : void 0,
    otherUseCase: data.other_use_case ? unmarshalQualificationOtherUseCase(data.other_use_case) : void 0,
    setScalewayEnvironment: data.set_scaleway_environment ? unmarshalQualificationSetScalewayEnvironment(
      data.set_scaleway_environment
    ) : void 0,
    shareData: data.share_data ? unmarshalQualificationShareData(data.share_data) : void 0
  };
};
const unmarshalProjectQualification = (data) => {
  if (!isJSONObject(data)) {
    throw new TypeError(
      `Unmarshalling the type 'ProjectQualification' failed as data isn't a dictionary.`
    );
  }
  return {
    projectId: data.project_id,
    qualification: data.qualification ? unmarshalQualification(data.qualification) : void 0
  };
};
const marshalContractApiCheckContractSignatureRequest = (request, defaults) => ({
  contract_name: request.contractName,
  contract_type: request.contractType,
  organization_id: request.organizationId ?? defaults.defaultOrganizationId
});
const marshalContractApiCreateContractSignatureRequest = (request, defaults) => ({
  contract_name: request.contractName,
  contract_type: request.contractType,
  organization_id: request.organizationId ?? defaults.defaultOrganizationId,
  validated: request.validated
});
const marshalProjectApiCreateProjectRequest = (request, defaults) => ({
  description: request.description,
  name: request.name || randomName("proj"),
  organization_id: request.organizationId ?? defaults.defaultOrganizationId
});
const marshalQualificationAiMachine = (request, defaults) => ({});
const marshalQualificationArchiveData = (request, defaults) => ({});
const marshalQualificationContainer = (request, defaults) => ({});
const marshalQualificationDeploySoftware = (request, defaults) => ({});
const marshalQualificationHostApplication = (request, defaults) => ({
  sub_use_case: request.subUseCase
});
const marshalQualificationHostWebsite = (request, defaults) => ({
  sub_use_case: request.subUseCase
});
const marshalQualificationOtherUseCase = (request, defaults) => ({});
const marshalQualificationSetScalewayEnvironment = (request, defaults) => ({});
const marshalQualificationShareData = (request, defaults) => ({});
const marshalQualification = (request, defaults) => ({
  architecture_type: request.architectureType,
  ...resolveOneOf([
    {
      param: "host_website",
      value: request.hostWebsite !== void 0 ? marshalQualificationHostWebsite(request.hostWebsite) : void 0
    },
    {
      param: "host_application",
      value: request.hostApplication !== void 0 ? marshalQualificationHostApplication(
        request.hostApplication
      ) : void 0
    },
    {
      param: "deploy_software",
      value: request.deploySoftware !== void 0 ? marshalQualificationDeploySoftware(request.deploySoftware) : void 0
    },
    {
      param: "set_scaleway_environment",
      value: request.setScalewayEnvironment !== void 0 ? marshalQualificationSetScalewayEnvironment(
        request.setScalewayEnvironment
      ) : void 0
    },
    {
      param: "ai_machine",
      value: request.aiMachine !== void 0 ? marshalQualificationAiMachine(request.aiMachine) : void 0
    },
    {
      param: "container",
      value: request.container !== void 0 ? marshalQualificationContainer(request.container) : void 0
    },
    {
      param: "archive_data",
      value: request.archiveData !== void 0 ? marshalQualificationArchiveData(request.archiveData) : void 0
    },
    {
      param: "share_data",
      value: request.shareData !== void 0 ? marshalQualificationShareData(request.shareData) : void 0
    },
    {
      param: "other_use_case",
      value: request.otherUseCase !== void 0 ? marshalQualificationOtherUseCase(request.otherUseCase) : void 0
    }
  ])
});
const marshalProjectApiSetProjectQualificationRequest = (request, defaults) => ({
  qualification: request.qualification !== void 0 ? marshalQualification(request.qualification) : void 0
});
const marshalProjectApiUpdateProjectRequest = (request, defaults) => ({
  description: request.description,
  name: request.name
});
export {
  marshalContractApiCheckContractSignatureRequest,
  marshalContractApiCreateContractSignatureRequest,
  marshalProjectApiCreateProjectRequest,
  marshalProjectApiSetProjectQualificationRequest,
  marshalProjectApiUpdateProjectRequest,
  unmarshalCheckContractSignatureResponse,
  unmarshalContractSignature,
  unmarshalListContractSignaturesResponse,
  unmarshalListProjectsResponse,
  unmarshalProject,
  unmarshalProjectQualification
};
