"use strict";
Object.defineProperty(exports, Symbol.toStringTag, { value: "Module" });
require("../../../client/dist/internal/logger/index.cjs");
const intervalRetrier = require("../../../client/dist/internal/async/interval-retrier.cjs");
require("../../../client/dist/vendor/base64/index.cjs");
const api_gen = require("./api.gen.cjs");
const content_gen = require("./content.gen.cjs");
class BaremetalV1UtilsAPI extends api_gen.API {
  /**
   * Waits for {@link ServerInstall} to be in a final state.
   *
   * @param request - The request {@link GetServerRequest}
   * @param options - The waiting options
   * @returns A Promise of ServerInstall
   */
  waitForServerInstall = (request, options) => intervalRetrier.tryAtIntervals(
    async () => {
      const value = await this.getServer(request).then((server) => {
        if (!server.install) {
          throw new Error(
            `Server creation has not begun for server ${request.serverId}`
          );
        }
        return server.install;
      });
      return {
        done: !content_gen.SERVER_INSTALL_TRANSIENT_STATUSES.includes(value.status),
        value
      };
    },
    intervalRetrier.createExponentialBackoffStrategy(
      options?.minDelay ?? 1,
      options?.maxDelay ?? 30
    ),
    options?.timeout
  );
}
exports.BaremetalV1UtilsAPI = BaremetalV1UtilsAPI;
