"use strict";
Object.defineProperty(exports, Symbol.toStringTag, { value: "Module" });
const randomName = require("@scaleway/random-name");
require("../../../client/dist/internal/logger/index.cjs");
const json = require("../../../client/dist/helpers/json.cjs");
const customMarshalling = require("../../../client/dist/scw/custom-marshalling.cjs");
const marshalling = require("../../../client/dist/helpers/marshalling.cjs");
const unmarshalContactPointEmail = (data) => {
  if (!json.isJSONObject(data)) {
    throw new TypeError(
      `Unmarshalling the type 'ContactPointEmail' failed as data isn't a dictionary.`
    );
  }
  return {
    to: data.to
  };
};
const unmarshalContactPoint = (data) => {
  if (!json.isJSONObject(data)) {
    throw new TypeError(
      `Unmarshalling the type 'ContactPoint' failed as data isn't a dictionary.`
    );
  }
  return {
    email: data.email ? unmarshalContactPointEmail(data.email) : void 0
  };
};
const unmarshalDatasource = (data) => {
  if (!json.isJSONObject(data)) {
    throw new TypeError(
      `Unmarshalling the type 'Datasource' failed as data isn't a dictionary.`
    );
  }
  return {
    id: data.id,
    isManagedByScaleway: data.is_managed_by_scaleway,
    name: data.name,
    projectId: data.project_id,
    type: data.type,
    url: data.url
  };
};
const unmarshalGrafanaProductDashboard = (data) => {
  if (!json.isJSONObject(data)) {
    throw new TypeError(
      `Unmarshalling the type 'GrafanaProductDashboard' failed as data isn't a dictionary.`
    );
  }
  return {
    dashboardName: data.dashboard_name,
    tags: data.tags,
    title: data.title,
    url: data.url,
    variables: data.variables
  };
};
const unmarshalGrafanaUser = (data) => {
  if (!json.isJSONObject(data)) {
    throw new TypeError(
      `Unmarshalling the type 'GrafanaUser' failed as data isn't a dictionary.`
    );
  }
  return {
    id: data.id,
    login: data.login,
    password: data.password,
    role: data.role
  };
};
const unmarshalTokenScopes = (data) => {
  if (!json.isJSONObject(data)) {
    throw new TypeError(
      `Unmarshalling the type 'TokenScopes' failed as data isn't a dictionary.`
    );
  }
  return {
    queryLogs: data.query_logs,
    queryMetrics: data.query_metrics,
    queryTraces: data.query_traces,
    setupAlerts: data.setup_alerts,
    setupLogsRules: data.setup_logs_rules,
    setupMetricsRules: data.setup_metrics_rules,
    writeLogs: data.write_logs,
    writeMetrics: data.write_metrics,
    writeTraces: data.write_traces
  };
};
const unmarshalToken = (data) => {
  if (!json.isJSONObject(data)) {
    throw new TypeError(
      `Unmarshalling the type 'Token' failed as data isn't a dictionary.`
    );
  }
  return {
    createdAt: marshalling.unmarshalDate(data.created_at),
    id: data.id,
    name: data.name,
    projectId: data.project_id,
    scopes: data.scopes ? unmarshalTokenScopes(data.scopes) : void 0,
    secretKey: data.secret_key,
    updatedAt: marshalling.unmarshalDate(data.updated_at)
  };
};
const unmarshalCockpitEndpoints = (data) => {
  if (!json.isJSONObject(data)) {
    throw new TypeError(
      `Unmarshalling the type 'CockpitEndpoints' failed as data isn't a dictionary.`
    );
  }
  return {
    alertmanagerUrl: data.alertmanager_url,
    grafanaUrl: data.grafana_url,
    logsUrl: data.logs_url,
    metricsUrl: data.metrics_url,
    tracesUrl: data.traces_url
  };
};
const unmarshalPlan = (data) => {
  if (!json.isJSONObject(data)) {
    throw new TypeError(
      `Unmarshalling the type 'Plan' failed as data isn't a dictionary.`
    );
  }
  return {
    id: data.id,
    logsIngestionPrice: data.logs_ingestion_price,
    name: data.name,
    retentionLogsInterval: data.retention_logs_interval,
    retentionMetricsInterval: data.retention_metrics_interval,
    retentionPrice: data.retention_price,
    retentionTracesInterval: data.retention_traces_interval,
    sampleIngestionPrice: data.sample_ingestion_price,
    tracesIngestionPrice: data.traces_ingestion_price
  };
};
const unmarshalCockpit = (data) => {
  if (!json.isJSONObject(data)) {
    throw new TypeError(
      `Unmarshalling the type 'Cockpit' failed as data isn't a dictionary.`
    );
  }
  return {
    createdAt: marshalling.unmarshalDate(data.created_at),
    endpoints: data.endpoints ? unmarshalCockpitEndpoints(data.endpoints) : void 0,
    managedAlertsEnabled: data.managed_alerts_enabled,
    plan: data.plan ? unmarshalPlan(data.plan) : void 0,
    projectId: data.project_id,
    status: data.status,
    updatedAt: marshalling.unmarshalDate(data.updated_at)
  };
};
const unmarshalCockpitMetrics = (data) => {
  if (!json.isJSONObject(data)) {
    throw new TypeError(
      `Unmarshalling the type 'CockpitMetrics' failed as data isn't a dictionary.`
    );
  }
  return {
    timeseries: marshalling.unmarshalArrayOfObject(data.timeseries, customMarshalling.unmarshalTimeSeries)
  };
};
const unmarshalListContactPointsResponse = (data) => {
  if (!json.isJSONObject(data)) {
    throw new TypeError(
      `Unmarshalling the type 'ListContactPointsResponse' failed as data isn't a dictionary.`
    );
  }
  return {
    contactPoints: marshalling.unmarshalArrayOfObject(
      data.contact_points,
      unmarshalContactPoint
    ),
    hasAdditionalContactPoints: data.has_additional_contact_points,
    hasAdditionalReceivers: data.has_additional_receivers,
    totalCount: data.total_count
  };
};
const unmarshalListDatasourcesResponse = (data) => {
  if (!json.isJSONObject(data)) {
    throw new TypeError(
      `Unmarshalling the type 'ListDatasourcesResponse' failed as data isn't a dictionary.`
    );
  }
  return {
    datasources: marshalling.unmarshalArrayOfObject(data.datasources, unmarshalDatasource),
    totalCount: data.total_count
  };
};
const unmarshalListGrafanaProductDashboardsResponse = (data) => {
  if (!json.isJSONObject(data)) {
    throw new TypeError(
      `Unmarshalling the type 'ListGrafanaProductDashboardsResponse' failed as data isn't a dictionary.`
    );
  }
  return {
    dashboards: marshalling.unmarshalArrayOfObject(
      data.dashboards,
      unmarshalGrafanaProductDashboard
    ),
    totalCount: data.total_count
  };
};
const unmarshalListGrafanaUsersResponse = (data) => {
  if (!json.isJSONObject(data)) {
    throw new TypeError(
      `Unmarshalling the type 'ListGrafanaUsersResponse' failed as data isn't a dictionary.`
    );
  }
  return {
    grafanaUsers: marshalling.unmarshalArrayOfObject(
      data.grafana_users,
      unmarshalGrafanaUser
    ),
    totalCount: data.total_count
  };
};
const unmarshalListPlansResponse = (data) => {
  if (!json.isJSONObject(data)) {
    throw new TypeError(
      `Unmarshalling the type 'ListPlansResponse' failed as data isn't a dictionary.`
    );
  }
  return {
    plans: marshalling.unmarshalArrayOfObject(data.plans, unmarshalPlan),
    totalCount: data.total_count
  };
};
const unmarshalListTokensResponse = (data) => {
  if (!json.isJSONObject(data)) {
    throw new TypeError(
      `Unmarshalling the type 'ListTokensResponse' failed as data isn't a dictionary.`
    );
  }
  return {
    tokens: marshalling.unmarshalArrayOfObject(data.tokens, unmarshalToken),
    totalCount: data.total_count
  };
};
const unmarshalSelectPlanResponse = (data) => {
  if (!json.isJSONObject(data)) {
    throw new TypeError(
      `Unmarshalling the type 'SelectPlanResponse' failed as data isn't a dictionary.`
    );
  }
  return {};
};
const marshalActivateCockpitRequest = (request, defaults) => ({
  project_id: request.projectId ?? defaults.defaultProjectId
});
const marshalContactPointEmail = (request, defaults) => ({
  to: request.to
});
const marshalContactPoint = (request, defaults) => ({
  ...marshalling.resolveOneOf([
    {
      param: "email",
      value: request.email !== void 0 ? marshalContactPointEmail(request.email) : void 0
    }
  ])
});
const marshalCreateContactPointRequest = (request, defaults) => ({
  contact_point: request.contactPoint !== void 0 ? marshalContactPoint(request.contactPoint) : void 0,
  project_id: request.projectId ?? defaults.defaultProjectId
});
const marshalCreateDatasourceRequest = (request, defaults) => ({
  is_default: request.isDefault,
  name: request.name,
  project_id: request.projectId ?? defaults.defaultProjectId,
  type: request.type
});
const marshalCreateGrafanaUserRequest = (request, defaults) => ({
  login: request.login,
  project_id: request.projectId ?? defaults.defaultProjectId,
  role: request.role
});
const marshalTokenScopes = (request, defaults) => ({
  query_logs: request.queryLogs,
  query_metrics: request.queryMetrics,
  query_traces: request.queryTraces,
  setup_alerts: request.setupAlerts,
  setup_logs_rules: request.setupLogsRules,
  setup_metrics_rules: request.setupMetricsRules,
  write_logs: request.writeLogs,
  write_metrics: request.writeMetrics,
  write_traces: request.writeTraces
});
const marshalCreateTokenRequest = (request, defaults) => ({
  name: request.name || randomName("token"),
  project_id: request.projectId ?? defaults.defaultProjectId,
  scopes: request.scopes !== void 0 ? marshalTokenScopes(request.scopes) : void 0
});
const marshalDeactivateCockpitRequest = (request, defaults) => ({
  project_id: request.projectId ?? defaults.defaultProjectId
});
const marshalDeleteContactPointRequest = (request, defaults) => ({
  contact_point: request.contactPoint !== void 0 ? marshalContactPoint(request.contactPoint) : void 0,
  project_id: request.projectId ?? defaults.defaultProjectId
});
const marshalDeleteGrafanaUserRequest = (request, defaults) => ({
  project_id: request.projectId ?? defaults.defaultProjectId
});
const marshalDisableManagedAlertsRequest = (request, defaults) => ({
  project_id: request.projectId ?? defaults.defaultProjectId
});
const marshalEnableManagedAlertsRequest = (request, defaults) => ({
  project_id: request.projectId ?? defaults.defaultProjectId
});
const marshalResetGrafanaUserPasswordRequest = (request, defaults) => ({
  project_id: request.projectId ?? defaults.defaultProjectId
});
const marshalSelectPlanRequest = (request, defaults) => ({
  plan_id: request.planId,
  project_id: request.projectId ?? defaults.defaultProjectId
});
const marshalTriggerTestAlertRequest = (request, defaults) => ({
  project_id: request.projectId ?? defaults.defaultProjectId
});
exports.marshalActivateCockpitRequest = marshalActivateCockpitRequest;
exports.marshalCreateContactPointRequest = marshalCreateContactPointRequest;
exports.marshalCreateDatasourceRequest = marshalCreateDatasourceRequest;
exports.marshalCreateGrafanaUserRequest = marshalCreateGrafanaUserRequest;
exports.marshalCreateTokenRequest = marshalCreateTokenRequest;
exports.marshalDeactivateCockpitRequest = marshalDeactivateCockpitRequest;
exports.marshalDeleteContactPointRequest = marshalDeleteContactPointRequest;
exports.marshalDeleteGrafanaUserRequest = marshalDeleteGrafanaUserRequest;
exports.marshalDisableManagedAlertsRequest = marshalDisableManagedAlertsRequest;
exports.marshalEnableManagedAlertsRequest = marshalEnableManagedAlertsRequest;
exports.marshalResetGrafanaUserPasswordRequest = marshalResetGrafanaUserPasswordRequest;
exports.marshalSelectPlanRequest = marshalSelectPlanRequest;
exports.marshalTriggerTestAlertRequest = marshalTriggerTestAlertRequest;
exports.unmarshalCockpit = unmarshalCockpit;
exports.unmarshalCockpitMetrics = unmarshalCockpitMetrics;
exports.unmarshalContactPoint = unmarshalContactPoint;
exports.unmarshalDatasource = unmarshalDatasource;
exports.unmarshalGrafanaProductDashboard = unmarshalGrafanaProductDashboard;
exports.unmarshalGrafanaUser = unmarshalGrafanaUser;
exports.unmarshalListContactPointsResponse = unmarshalListContactPointsResponse;
exports.unmarshalListDatasourcesResponse = unmarshalListDatasourcesResponse;
exports.unmarshalListGrafanaProductDashboardsResponse = unmarshalListGrafanaProductDashboardsResponse;
exports.unmarshalListGrafanaUsersResponse = unmarshalListGrafanaUsersResponse;
exports.unmarshalListPlansResponse = unmarshalListPlansResponse;
exports.unmarshalListTokensResponse = unmarshalListTokensResponse;
exports.unmarshalSelectPlanResponse = unmarshalSelectPlanResponse;
exports.unmarshalToken = unmarshalToken;
