import { API as ParentAPI } from '@scaleway/sdk-client';
import type { Region, WaitForOptions } from '@scaleway/sdk-client';
import type { AddInstanceACLRulesRequest, AddInstanceACLRulesResponse, AddInstanceSettingsRequest, AddInstanceSettingsResponse, ApplyInstanceMaintenanceRequest, CloneInstanceRequest, CreateDatabaseRequest, CreateEndpointRequest, CreateInstanceFromSnapshotRequest, CreateInstanceRequest, CreateReadReplicaEndpointRequest, CreateReadReplicaRequest, CreateSnapshotRequest, CreateUserRequest, Database, DeleteDatabaseRequest, DeleteEndpointRequest, DeleteInstanceACLRulesRequest, DeleteInstanceACLRulesResponse, DeleteInstanceRequest, DeleteInstanceSettingsRequest, DeleteInstanceSettingsResponse, DeleteReadReplicaRequest, DeleteSnapshotRequest, DeleteUserRequest, Endpoint, GetEndpointRequest, GetInstanceCertificateRequest, GetInstanceLogRequest, GetInstanceMetricsRequest, GetInstanceRequest, GetReadReplicaRequest, GetSnapshotRequest, Instance, InstanceLog, InstanceMetrics, ListDatabaseEnginesRequest, ListDatabaseEnginesResponse, ListDatabasesRequest, ListDatabasesResponse, ListInstanceACLRulesRequest, ListInstanceACLRulesResponse, ListInstanceLogsDetailsRequest, ListInstanceLogsDetailsResponse, ListInstanceLogsRequest, ListInstanceLogsResponse, ListInstancesRequest, ListInstancesResponse, ListNodeTypesRequest, ListNodeTypesResponse, ListPrivilegesRequest, ListPrivilegesResponse, ListSnapshotsRequest, ListSnapshotsResponse, ListUsersRequest, ListUsersResponse, Maintenance, MigrateEndpointRequest, Privilege, PromoteReadReplicaRequest, PurgeInstanceLogsRequest, ReadReplica, RenewInstanceCertificateRequest, ResetReadReplicaRequest, RestartInstanceRequest, SetInstanceACLRulesRequest, SetInstanceACLRulesResponse, SetInstanceSettingsRequest, SetInstanceSettingsResponse, SetPrivilegeRequest, Snapshot, UpdateInstanceRequest, UpdateSnapshotRequest, UpdateUserRequest, UpgradeInstanceRequest, User } from './types.gen';
/**
 * Managed Document Databases API.
 *
 * This API allows you to manage your Document Databases.
 */
export declare class API extends ParentAPI {
    /** Lists the available regions of the API. */
    static readonly LOCALITIES: Region[];
    protected pageOfListDatabaseEngines: (request?: Readonly<ListDatabaseEnginesRequest>) => Promise<ListDatabaseEnginesResponse>;
    /**
     * List available database engines. List the FerretDB database engines
     * available at Scaleway.
     *
     * @param request - The request {@link ListDatabaseEnginesRequest}
     * @returns A Promise of ListDatabaseEnginesResponse
     */
    listDatabaseEngines: (request?: Readonly<ListDatabaseEnginesRequest>) => Promise<ListDatabaseEnginesResponse> & {
        all: () => Promise<import("./types.gen").DatabaseEngine[]>;
        [Symbol.asyncIterator]: () => AsyncGenerator<import("./types.gen").DatabaseEngine[], void, void>;
    };
    protected pageOfListNodeTypes: (request: Readonly<ListNodeTypesRequest>) => Promise<ListNodeTypesResponse>;
    /**
     * List available node types. List all available node types. By default, the
     * node types returned in the list are ordered by creation date in ascending
     * order, though this can be modified via the `order_by` field.
     *
     * @param request - The request {@link ListNodeTypesRequest}
     * @returns A Promise of ListNodeTypesResponse
     */
    listNodeTypes: (request: Readonly<ListNodeTypesRequest>) => Promise<ListNodeTypesResponse> & {
        all: () => Promise<import("./types.gen").NodeType[]>;
        [Symbol.asyncIterator]: () => AsyncGenerator<import("./types.gen").NodeType[], void, void>;
    };
    /**
     * Upgrade a Database Instance. Upgrade your current Database Instance
     * specifications like node type, high availability, volume, or the database
     * engine version. Note that upon upgrade the `enable_ha` parameter can only
     * be set to `true`.
     *
     * @param request - The request {@link UpgradeInstanceRequest}
     * @returns A Promise of Instance
     */
    upgradeInstance: (request: Readonly<UpgradeInstanceRequest>) => Promise<Instance>;
    protected pageOfListInstances: (request?: Readonly<ListInstancesRequest>) => Promise<ListInstancesResponse>;
    /**
     * List Database Instances. List all Database Instances in the specified
     * region, for a given Scaleway Organization or Scaleway Project. By default,
     * the Database Instances returned in the list are ordered by creation date in
     * ascending order, though this can be modified via the order_by field. You
     * can define additional parameters for your query, such as `tags` and `name`.
     * For the `name` parameter, the value you include will be checked against the
     * whole name string to see if it includes the string you put in the
     * parameter.
     *
     * @param request - The request {@link ListInstancesRequest}
     * @returns A Promise of ListInstancesResponse
     */
    listInstances: (request?: Readonly<ListInstancesRequest>) => Promise<ListInstancesResponse> & {
        all: () => Promise<Instance[]>;
        [Symbol.asyncIterator]: () => AsyncGenerator<Instance[], void, void>;
    };
    /**
     * Get a Database Instance. Retrieve information about a given Database
     * Instance, specified by the `region` and `instance_id` parameters. Its full
     * details, including name, status, IP address and port, are returned in the
     * response object.
     *
     * @param request - The request {@link GetInstanceRequest}
     * @returns A Promise of Instance
     */
    getInstance: (request: Readonly<GetInstanceRequest>) => Promise<Instance>;
    /**
     * Waits for {@link Instance} to be in a final state.
     *
     * @param request - The request {@link GetInstanceRequest}
     * @param options - The waiting options
     * @returns A Promise of Instance
     */
    waitForInstance: (request: Readonly<GetInstanceRequest>, options?: Readonly<WaitForOptions<Instance>>) => Promise<Instance>;
    /**
     * Create a Database Instance. Create a new Database Instance. You must set
     * the `engine`, `user_name`, `password` and `node_type` parameters.
     * Optionally, you can specify the volume type and size.
     *
     * @param request - The request {@link CreateInstanceRequest}
     * @returns A Promise of Instance
     */
    createInstance: (request: Readonly<CreateInstanceRequest>) => Promise<Instance>;
    /**
     * Update a Database Instance. Update the parameters of a Database Instance,
     * including name, tags and backup schedule details.
     *
     * @param request - The request {@link UpdateInstanceRequest}
     * @returns A Promise of Instance
     */
    updateInstance: (request: Readonly<UpdateInstanceRequest>) => Promise<Instance>;
    /**
     * Delete a Database Instance. Delete a given Database Instance, specified by
     * the `region` and `instance_id` parameters. Deleting a Database Instance is
     * permanent, and cannot be undone. Note that upon deletion all your data will
     * be lost.
     *
     * @param request - The request {@link DeleteInstanceRequest}
     * @returns A Promise of Instance
     */
    deleteInstance: (request: Readonly<DeleteInstanceRequest>) => Promise<Instance>;
    /**
     * Clone a Database Instance. Clone a given Database Instance, specified by
     * the `region` and `instance_id` parameters. The clone feature allows you to
     * create a new Database Instance from an existing one. The clone includes all
     * existing databases, users and permissions. You can create a clone on a
     * Database Instance bigger than your current one.
     *
     * @param request - The request {@link CloneInstanceRequest}
     * @returns A Promise of Instance
     */
    cloneInstance: (request: Readonly<CloneInstanceRequest>) => Promise<Instance>;
    /**
     * Restart Database Instance. Restart a given Database Instance, specified by
     * the `region` and `instance_id` parameters. The status of the Database
     * Instance returned in the response.
     *
     * @param request - The request {@link RestartInstanceRequest}
     * @returns A Promise of Instance
     */
    restartInstance: (request: Readonly<RestartInstanceRequest>) => Promise<Instance>;
    /**
     * Get the TLS certificate of a Database Instance. Retrieve information about
     * the TLS certificate of a given Database Instance. Details like name and
     * content are returned in the response.
     *
     * @param request - The request {@link GetInstanceCertificateRequest}
     * @returns A Promise of Blob
     */
    getInstanceCertificate: (request: Readonly<GetInstanceCertificateRequest>) => Promise<Blob>;
    /**
     * Renew the TLS certificate of a Database Instance. Renew a TLS for a
     * Database Instance. Renewing a certificate means that you will not be able
     * to connect to your Database Instance using the previous certificate. You
     * will also need to download and update the new certificate for all database
     * clients.
     *
     * @param request - The request {@link RenewInstanceCertificateRequest}
     */
    renewInstanceCertificate: (request: Readonly<RenewInstanceCertificateRequest>) => Promise<void>;
    /**
     * Get Database Instance metrics. Retrieve the time series metrics of a given
     * Database Instance. You can define the period from which to retrieve metrics
     * by specifying the `start_date` and `end_date`.
     *
     * @param request - The request {@link GetInstanceMetricsRequest}
     * @returns A Promise of InstanceMetrics
     */
    getInstanceMetrics: (request: Readonly<GetInstanceMetricsRequest>) => Promise<InstanceMetrics>;
    /**
     * Create a Read Replica. Create a new Read Replica of a Database Instance.
     * You must specify the `region` and the `instance_id`. You can only create a
     * maximum of 3 Read Replicas per Database Instance.
     *
     * @param request - The request {@link CreateReadReplicaRequest}
     * @returns A Promise of ReadReplica
     */
    createReadReplica: (request: Readonly<CreateReadReplicaRequest>) => Promise<ReadReplica>;
    /**
     * Get a Read Replica. Retrieve information about a Database Instance Read
     * Replica. Full details about the Read Replica, like `endpoints`, `status`
     * and `region` are returned in the response.
     *
     * @param request - The request {@link GetReadReplicaRequest}
     * @returns A Promise of ReadReplica
     */
    getReadReplica: (request: Readonly<GetReadReplicaRequest>) => Promise<ReadReplica>;
    /**
     * Waits for {@link ReadReplica} to be in a final state.
     *
     * @param request - The request {@link GetReadReplicaRequest}
     * @param options - The waiting options
     * @returns A Promise of ReadReplica
     */
    waitForReadReplica: (request: Readonly<GetReadReplicaRequest>, options?: Readonly<WaitForOptions<ReadReplica>>) => Promise<ReadReplica>;
    /**
     * Delete a Read Replica. Delete a Read Replica of a Database Instance. You
     * must specify the `region` and `read_replica_id` parameters of the Read
     * Replica you want to delete.
     *
     * @param request - The request {@link DeleteReadReplicaRequest}
     * @returns A Promise of ReadReplica
     */
    deleteReadReplica: (request: Readonly<DeleteReadReplicaRequest>) => Promise<ReadReplica>;
    /**
     * Resync a Read Replica. When you resync a Read Replica, first it is reset,
     * then its data is resynchronized from the primary node. Your Read Replica
     * remains unavailable during the resync process. The duration of this process
     * is proportional to the size of your Database Instance. The configured
     * endpoints do not change.
     *
     * @param request - The request {@link ResetReadReplicaRequest}
     * @returns A Promise of ReadReplica
     */
    resetReadReplica: (request: Readonly<ResetReadReplicaRequest>) => Promise<ReadReplica>;
    /**
     * Promote a Read Replica. Promote a Read Replica to Database Instance
     * automatically.
     *
     * @param request - The request {@link PromoteReadReplicaRequest}
     * @returns A Promise of Instance
     */
    promoteReadReplica: (request: Readonly<PromoteReadReplicaRequest>) => Promise<Instance>;
    /**
     * Create an endpoint for a Read Replica. Create a new endpoint for a Read
     * Replica. Read Replicas can have at most one direct access and one Private
     * Network endpoint.
     *
     * @param request - The request {@link CreateReadReplicaEndpointRequest}
     * @returns A Promise of ReadReplica
     */
    createReadReplicaEndpoint: (request: Readonly<CreateReadReplicaEndpointRequest>) => Promise<ReadReplica>;
    /**
     * List available logs of a Database Instance. List the available logs of a
     * Database Instance. By default, the logs returned in the list are ordered by
     * creation date in ascending order, though this can be modified via the
     * order_by field.
     *
     * @param request - The request {@link ListInstanceLogsRequest}
     * @returns A Promise of ListInstanceLogsResponse
     */
    listInstanceLogs: (request: Readonly<ListInstanceLogsRequest>) => Promise<ListInstanceLogsResponse>;
    /**
     * Get given logs of a Database Instance. Retrieve information about the logs
     * of a Database Instance. Specify the `instance_log_id` and `region` in your
     * request to get information such as `download_url`, `status`, `expires_at`
     * and `created_at` about your logs in the response.
     *
     * @param request - The request {@link GetInstanceLogRequest}
     * @returns A Promise of InstanceLog
     */
    getInstanceLog: (request: Readonly<GetInstanceLogRequest>) => Promise<InstanceLog>;
    /**
     * Waits for {@link InstanceLog} to be in a final state.
     *
     * @param request - The request {@link GetInstanceLogRequest}
     * @param options - The waiting options
     * @returns A Promise of InstanceLog
     */
    waitForInstanceLog: (request: Readonly<GetInstanceLogRequest>, options?: Readonly<WaitForOptions<InstanceLog>>) => Promise<InstanceLog>;
    /**
     * Purge remote Database Instance logs. Purge a given remote log from a
     * Database Instance. You can specify the `log_name` of the log you wish to
     * clean from your Database Instance.
     *
     * @param request - The request {@link PurgeInstanceLogsRequest}
     */
    purgeInstanceLogs: (request: Readonly<PurgeInstanceLogsRequest>) => Promise<void>;
    /**
     * List remote Database Instance logs details. List remote log details. By
     * default, the details returned in the list are ordered by creation date in
     * ascending order, though this can be modified via the order_by field.
     *
     * @param request - The request {@link ListInstanceLogsDetailsRequest}
     * @returns A Promise of ListInstanceLogsDetailsResponse
     */
    listInstanceLogsDetails: (request: Readonly<ListInstanceLogsDetailsRequest>) => Promise<ListInstanceLogsDetailsResponse>;
    /**
     * Add Database Instance advanced settings. Add an advanced setting to a
     * Database Instance. You must set the `name` and the `value` of each
     * setting.
     *
     * @param request - The request {@link AddInstanceSettingsRequest}
     * @returns A Promise of AddInstanceSettingsResponse
     */
    addInstanceSettings: (request: Readonly<AddInstanceSettingsRequest>) => Promise<AddInstanceSettingsResponse>;
    /**
     * Delete Database Instance advanced settings. Delete an advanced setting in a
     * Database Instance. You must specify the names of the settings you want to
     * delete in the request.
     *
     * @param request - The request {@link DeleteInstanceSettingsRequest}
     * @returns A Promise of DeleteInstanceSettingsResponse
     */
    deleteInstanceSettings: (request: Readonly<DeleteInstanceSettingsRequest>) => Promise<DeleteInstanceSettingsResponse>;
    /**
     * Set Database Instance advanced settings. Update an advanced setting for a
     * Database Instance. Settings added upon database engine initalization can
     * only be defined once, and cannot, therefore, be updated.
     *
     * @param request - The request {@link SetInstanceSettingsRequest}
     * @returns A Promise of SetInstanceSettingsResponse
     */
    setInstanceSettings: (request: Readonly<SetInstanceSettingsRequest>) => Promise<SetInstanceSettingsResponse>;
    protected pageOfListInstanceACLRules: (request: Readonly<ListInstanceACLRulesRequest>) => Promise<ListInstanceACLRulesResponse>;
    /**
     * List ACL rules of a Database Instance. List the ACL rules for a given
     * Database Instance. The response is an array of ACL objects, each one
     * representing an ACL that denies, allows or redirects traffic based on
     * certain conditions.
     *
     * @param request - The request {@link ListInstanceACLRulesRequest}
     * @returns A Promise of ListInstanceACLRulesResponse
     */
    listInstanceACLRules: (request: Readonly<ListInstanceACLRulesRequest>) => Promise<ListInstanceACLRulesResponse> & {
        all: () => Promise<import("./types.gen").ACLRule[]>;
        [Symbol.asyncIterator]: () => AsyncGenerator<import("./types.gen").ACLRule[], void, void>;
    };
    /**
     * Add an ACL rule to a Database Instance. Add an additional ACL rule to a
     * Database Instance.
     *
     * @param request - The request {@link AddInstanceACLRulesRequest}
     * @returns A Promise of AddInstanceACLRulesResponse
     */
    addInstanceACLRules: (request: Readonly<AddInstanceACLRulesRequest>) => Promise<AddInstanceACLRulesResponse>;
    /**
     * Set ACL rules for a Database Instance. Replace all the ACL rules of a
     * Database Instance.
     *
     * @param request - The request {@link SetInstanceACLRulesRequest}
     * @returns A Promise of SetInstanceACLRulesResponse
     */
    setInstanceACLRules: (request: Readonly<SetInstanceACLRulesRequest>) => Promise<SetInstanceACLRulesResponse>;
    /**
     * Delete ACL rules of a Database Instance. Delete one or more ACL rules of a
     * Database Instance.
     *
     * @param request - The request {@link DeleteInstanceACLRulesRequest}
     * @returns A Promise of DeleteInstanceACLRulesResponse
     */
    deleteInstanceACLRules: (request: Readonly<DeleteInstanceACLRulesRequest>) => Promise<DeleteInstanceACLRulesResponse>;
    protected pageOfListUsers: (request: Readonly<ListUsersRequest>) => Promise<ListUsersResponse>;
    /**
     * List users of a Database Instance. List all users of a given Database
     * Instance. By default, the users returned in the list are ordered by
     * creation date in ascending order, though this can be modified via the
     * order_by field.
     *
     * @param request - The request {@link ListUsersRequest}
     * @returns A Promise of ListUsersResponse
     */
    listUsers: (request: Readonly<ListUsersRequest>) => Promise<ListUsersResponse> & {
        all: () => Promise<User[]>;
        [Symbol.asyncIterator]: () => AsyncGenerator<User[], void, void>;
    };
    /**
     * Create a user for a Database Instance. Create a new user for a Database
     * Instance. You must define the `name`, `password` and `is_admin`
     * parameters.
     *
     * @param request - The request {@link CreateUserRequest}
     * @returns A Promise of User
     */
    createUser: (request: Readonly<CreateUserRequest>) => Promise<User>;
    /**
     * Update a user on a Database Instance. Update the parameters of a user on a
     * Database Instance. You can update the `password` and `is_admin` parameters,
     * but you cannot change the name of the user.
     *
     * @param request - The request {@link UpdateUserRequest}
     * @returns A Promise of User
     */
    updateUser: (request: Readonly<UpdateUserRequest>) => Promise<User>;
    /**
     * Delete a user on a Database Instance. Delete a given user on a Database
     * Instance. You must specify, in the endpoint, the `region`, `instance_id`
     * and `name` parameters of the user you want to delete.
     *
     * @param request - The request {@link DeleteUserRequest}
     */
    deleteUser: (request: Readonly<DeleteUserRequest>) => Promise<void>;
    protected pageOfListDatabases: (request: Readonly<ListDatabasesRequest>) => Promise<ListDatabasesResponse>;
    /**
     * List databases in a Database Instance. List all databases of a given
     * Database Instance. By default, the databases returned in the list are
     * ordered by creation date in ascending order, though this can be modified
     * via the order_by field. You can define additional parameters for your
     * query, such as `name`, `managed` and `owner`.
     *
     * @param request - The request {@link ListDatabasesRequest}
     * @returns A Promise of ListDatabasesResponse
     */
    listDatabases: (request: Readonly<ListDatabasesRequest>) => Promise<ListDatabasesResponse> & {
        all: () => Promise<Database[]>;
        [Symbol.asyncIterator]: () => AsyncGenerator<Database[], void, void>;
    };
    /**
     * Create a database in a Database Instance. Create a new database. You must
     * define the `name` parameter in the request.
     *
     * @param request - The request {@link CreateDatabaseRequest}
     * @returns A Promise of Database
     */
    createDatabase: (request: Readonly<CreateDatabaseRequest>) => Promise<Database>;
    /**
     * Delete a database in a Database Instance. Delete a given database on a
     * Database Instance. You must specify, in the endpoint, the `region`,
     * `instance_id` and `name` parameters of the database you want to delete.
     *
     * @param request - The request {@link DeleteDatabaseRequest}
     */
    deleteDatabase: (request: Readonly<DeleteDatabaseRequest>) => Promise<void>;
    protected pageOfListPrivileges: (request: Readonly<ListPrivilegesRequest>) => Promise<ListPrivilegesResponse>;
    /**
     * List user privileges for a database. List privileges of a user on a
     * database. By default, the details returned in the list are ordered by
     * creation date in ascending order, though this can be modified via the
     * order_by field. You can define additional parameters for your query, such
     * as `database_name` and `user_name`.
     *
     * @param request - The request {@link ListPrivilegesRequest}
     * @returns A Promise of ListPrivilegesResponse
     */
    listPrivileges: (request: Readonly<ListPrivilegesRequest>) => Promise<ListPrivilegesResponse> & {
        all: () => Promise<Privilege[]>;
        [Symbol.asyncIterator]: () => AsyncGenerator<Privilege[], void, void>;
    };
    /**
     * Set user privileges for a database. Set the privileges of a user on a
     * database. You must define `database_name`, `user_name` and `permission` in
     * the request body.
     *
     * @param request - The request {@link SetPrivilegeRequest}
     * @returns A Promise of Privilege
     */
    setPrivilege: (request: Readonly<SetPrivilegeRequest>) => Promise<Privilege>;
    protected pageOfListSnapshots: (request?: Readonly<ListSnapshotsRequest>) => Promise<ListSnapshotsResponse>;
    /**
     * List snapshots. List snapshots. You can include the `instance_id` or
     * `project_id` in your query to get the list of snapshots for specific
     * Database Instances and/or Projects. By default, the details returned in the
     * list are ordered by creation date in ascending order, though this can be
     * modified via the `order_by` field.
     *
     * @param request - The request {@link ListSnapshotsRequest}
     * @returns A Promise of ListSnapshotsResponse
     */
    listSnapshots: (request?: Readonly<ListSnapshotsRequest>) => Promise<ListSnapshotsResponse> & {
        all: () => Promise<Snapshot[]>;
        [Symbol.asyncIterator]: () => AsyncGenerator<Snapshot[], void, void>;
    };
    /**
     * Get a Database Instance snapshot. Retrieve information about a given
     * snapshot, specified by its `snapshot_id` and `region`. Full details about
     * the snapshot, like size and expiration date, are returned in the response.
     *
     * @param request - The request {@link GetSnapshotRequest}
     * @returns A Promise of Snapshot
     */
    getSnapshot: (request: Readonly<GetSnapshotRequest>) => Promise<Snapshot>;
    /**
     * Waits for {@link Snapshot} to be in a final state.
     *
     * @param request - The request {@link GetSnapshotRequest}
     * @param options - The waiting options
     * @returns A Promise of Snapshot
     */
    waitForSnapshot: (request: Readonly<GetSnapshotRequest>, options?: Readonly<WaitForOptions<Snapshot>>) => Promise<Snapshot>;
    /**
     * Create a Database Instance snapshot. Create a new snapshot of a Database
     * Instance. You must define the `name` parameter in the request.
     *
     * @param request - The request {@link CreateSnapshotRequest}
     * @returns A Promise of Snapshot
     */
    createSnapshot: (request: Readonly<CreateSnapshotRequest>) => Promise<Snapshot>;
    /**
     * Update a Database Instance snapshot. Update the parameters of a snapshot of
     * a Database Instance. You can update the `name` and `expires_at`
     * parameters.
     *
     * @param request - The request {@link UpdateSnapshotRequest}
     * @returns A Promise of Snapshot
     */
    updateSnapshot: (request: Readonly<UpdateSnapshotRequest>) => Promise<Snapshot>;
    /**
     * Delete a Database Instance snapshot. Delete a given snapshot of a Database
     * Instance. You must specify, in the endpoint, the `region` and `snapshot_id`
     * parameters of the snapshot you want to delete.
     *
     * @param request - The request {@link DeleteSnapshotRequest}
     * @returns A Promise of Snapshot
     */
    deleteSnapshot: (request: Readonly<DeleteSnapshotRequest>) => Promise<Snapshot>;
    /**
     * Create a new Database Instance from a snapshot. Restore a snapshot. When
     * you restore a snapshot, a new Instance is created and billed to your
     * account. Note that is possible to select a larger node type for your new
     * Database Instance. However, the Block volume size will be the same as the
     * size of the restored snapshot. All Instance settings will be restored if
     * you chose a node type with the same or more memory size than the initial
     * Instance. Settings will be reset to the default if your node type has less
     * memory.
     *
     * @param request - The request {@link CreateInstanceFromSnapshotRequest}
     * @returns A Promise of Instance
     */
    createInstanceFromSnapshot: (request: Readonly<CreateInstanceFromSnapshotRequest>) => Promise<Instance>;
    /**
     * Create a new Database Instance endpoint. Create a new endpoint for a
     * Database Instance. You can add `load_balancer` and `private_network`
     * specifications to the body of the request.
     *
     * @param request - The request {@link CreateEndpointRequest}
     * @returns A Promise of Endpoint
     */
    createEndpoint: (request: Readonly<CreateEndpointRequest>) => Promise<Endpoint>;
    /**
     * Delete a Database Instance endpoint. Delete the endpoint of a Database
     * Instance. You must specify the `region` and `endpoint_id` parameters of the
     * endpoint you want to delete. Note that might need to update any environment
     * configurations that point to the deleted endpoint.
     *
     * @param request - The request {@link DeleteEndpointRequest}
     */
    deleteEndpoint: (request: Readonly<DeleteEndpointRequest>) => Promise<void>;
    /**
     * Get a Database Instance endpoint. Retrieve information about a Database
     * Instance endpoint. Full details about the endpoint, like `ip`, `port`,
     * `private_network` and `load_balancer` specifications are returned in the
     * response.
     *
     * @param request - The request {@link GetEndpointRequest}
     * @returns A Promise of Endpoint
     */
    getEndpoint: (request: Readonly<GetEndpointRequest>) => Promise<Endpoint>;
    /**
     * Migrate Database Instance endpoint. Migrate an existing Database Instance
     * endpoint to another Database Instance.
     *
     * @param request - The request {@link MigrateEndpointRequest}
     * @returns A Promise of Endpoint
     */
    migrateEndpoint: (request: Readonly<MigrateEndpointRequest>) => Promise<Endpoint>;
    /**
     * Apply an instance maintenance. Apply a pending instance maintenance on your
     * instance. This action can generate some service interruption.
     *
     * @param request - The request {@link ApplyInstanceMaintenanceRequest}
     * @returns A Promise of Maintenance
     */
    applyInstanceMaintenance: (request: Readonly<ApplyInstanceMaintenanceRequest>) => Promise<Maintenance>;
}
