import { API as ParentAPI } from '@scaleway/sdk-client';
import type { Region, WaitForOptions } from '@scaleway/sdk-client';
import type { CreatePinByCIDRequest, CreatePinByURLRequest, CreateVolumeRequest, DeletePinRequest, DeleteVolumeRequest, ExportKeyNameResponse, GetPinRequest, GetVolumeRequest, IpnsApiCreateNameRequest, IpnsApiDeleteNameRequest, IpnsApiExportKeyNameRequest, IpnsApiGetNameRequest, IpnsApiImportKeyNameRequest, IpnsApiListNamesRequest, IpnsApiUpdateNameRequest, ListNamesResponse, ListPinsRequest, ListPinsResponse, ListVolumesRequest, ListVolumesResponse, Name, Pin, ReplacePinRequest, ReplacePinResponse, UpdateVolumeRequest, Volume } from './types.gen';
/** IPFS Pinning service API. */
export declare class API extends ParentAPI {
    /** Lists the available regions of the API. */
    static readonly LOCALITIES: Region[];
    /**
     * Create a new volume. Create a new volume from a Project ID. Volume is
     * identified by an ID and used to host pin references. Volume is personal (at
     * least to your organization) even if IPFS blocks and CID are available to
     * anyone. Should be the first command you made because every pin must be
     * attached to a volume.
     *
     * @param request - The request {@link CreateVolumeRequest}
     * @returns A Promise of Volume
     */
    createVolume: (request: Readonly<CreateVolumeRequest>) => Promise<Volume>;
    /**
     * Get information about a volume. Retrieve information about a specific
     * volume.
     *
     * @param request - The request {@link GetVolumeRequest}
     * @returns A Promise of Volume
     */
    getVolume: (request: Readonly<GetVolumeRequest>) => Promise<Volume>;
    protected pageOfListVolumes: (request?: Readonly<ListVolumesRequest>) => Promise<ListVolumesResponse>;
    /**
     * List all volumes by a Project ID. Retrieve information about all volumes
     * from a Project ID.
     *
     * @param request - The request {@link ListVolumesRequest}
     * @returns A Promise of ListVolumesResponse
     */
    listVolumes: (request?: Readonly<ListVolumesRequest>) => Promise<ListVolumesResponse> & {
        all: () => Promise<Volume[]>;
        [Symbol.asyncIterator]: () => AsyncGenerator<Volume[], void, void>;
    };
    /**
     * Update volume information. Update volume information (tag, name...).
     *
     * @param request - The request {@link UpdateVolumeRequest}
     * @returns A Promise of Volume
     */
    updateVolume: (request: Readonly<UpdateVolumeRequest>) => Promise<Volume>;
    /**
     * Delete an existing volume. Delete a volume by its ID and every pin attached
     * to this volume. This process can take a while to conclude, depending on the
     * size of your pinned content.
     *
     * @param request - The request {@link DeleteVolumeRequest}
     */
    deleteVolume: (request: Readonly<DeleteVolumeRequest>) => Promise<void>;
    /**
     * Create a pin by URL. Will fetch and store the content pointed by the
     * provided URL. The content must be available on the public IPFS network. The
     * content (IPFS blocks) will be host by the pinning service until pin
     * deletion. From that point, any other IPFS peer can fetch and host your
     * content: Make sure to pin public or encrypted content. Many pin requests
     * (from different users) can target the same CID. A pin is defined by its ID
     * (UUID), its status (queued, pinning, pinned or failed) and target CID.
     *
     * @param request - The request {@link CreatePinByURLRequest}
     * @returns A Promise of Pin
     */
    createPinByURL: (request: Readonly<CreatePinByURLRequest>) => Promise<Pin>;
    /**
     * Create a pin by CID. Will fetch and store the content pointed by the
     * provided CID. The content must be available on the public IPFS network. The
     * content (IPFS blocks) will be host by the pinning service until pin
     * deletion. From that point, any other IPFS peer can fetch and host your
     * content: Make sure to pin public or encrypted content. Many pin requests
     * (from different users) can target the same CID. A pin is defined by its ID
     * (UUID), its status (queued, pinning, pinned or failed) and target CID.
     *
     * @param request - The request {@link CreatePinByCIDRequest}
     * @returns A Promise of Pin
     */
    createPinByCID: (request: Readonly<CreatePinByCIDRequest>) => Promise<Pin>;
    /**
     * Replace pin by CID. Deletes the given resource ID and pins the new CID in
     * its place. Will fetch and store the content pointed by the provided CID.
     * The content must be available on the public IPFS network. The content (IPFS
     * blocks) is hosted by the pinning service until the pin is deleted. While
     * the content is available any other IPFS peer can fetch and host your
     * content. For this reason, we recommend that you pin either public or
     * encrypted content. Several different pin requests can target the same CID.
     * A pin is defined by its ID (UUID), its status (queued, pinning, pinned or
     * failed) and target CID.
     *
     * @param request - The request {@link ReplacePinRequest}
     * @returns A Promise of ReplacePinResponse
     */
    replacePin: (request: Readonly<ReplacePinRequest>) => Promise<ReplacePinResponse>;
    /**
     * Get pin information. Retrieve information about the provided **pin ID**,
     * such as status, last modification, and CID.
     *
     * @param request - The request {@link GetPinRequest}
     * @returns A Promise of Pin
     */
    getPin: (request: Readonly<GetPinRequest>) => Promise<Pin>;
    /**
     * Waits for {@link Pin} to be in a final state.
     *
     * @param request - The request {@link GetPinRequest}
     * @param options - The waiting options
     * @returns A Promise of Pin
     */
    waitForPin: (request: Readonly<GetPinRequest>, options?: Readonly<WaitForOptions<Pin>>) => Promise<Pin>;
    protected pageOfListPins: (request: Readonly<ListPinsRequest>) => Promise<ListPinsResponse>;
    /**
     * List all pins within a volume. Retrieve information about all pins within a
     * volume.
     *
     * @param request - The request {@link ListPinsRequest}
     * @returns A Promise of ListPinsResponse
     */
    listPins: (request: Readonly<ListPinsRequest>) => Promise<ListPinsResponse> & {
        all: () => Promise<Pin[]>;
        [Symbol.asyncIterator]: () => AsyncGenerator<Pin[], void, void>;
    };
    /**
     * Create an unpin request. An unpin request means that you no longer own the
     * content. This content can therefore be removed and no longer provided on
     * the IPFS network.
     *
     * @param request - The request {@link DeletePinRequest}
     */
    deletePin: (request: Readonly<DeletePinRequest>) => Promise<void>;
}
/** IPFS Naming service API. */
export declare class IpnsAPI extends ParentAPI {
    /** Lists the available regions of the API. */
    static readonly LOCALITIES: Region[];
    /**
     * Create a new name. You can use the `ipns key` command to list and generate
     * more names and their respective keys.
     *
     * @param request - The request {@link IpnsApiCreateNameRequest}
     * @returns A Promise of Name
     */
    createName: (request: Readonly<IpnsApiCreateNameRequest>) => Promise<Name>;
    /**
     * Get information about a name. Retrieve information about a specific name.
     *
     * @param request - The request {@link IpnsApiGetNameRequest}
     * @returns A Promise of Name
     */
    getName: (request: Readonly<IpnsApiGetNameRequest>) => Promise<Name>;
    /**
     * Waits for {@link Name} to be in a final state.
     *
     * @param request - The request {@link IpnsApiGetNameRequest}
     * @param options - The waiting options
     * @returns A Promise of Name
     */
    waitForName: (request: Readonly<IpnsApiGetNameRequest>, options?: Readonly<WaitForOptions<Name>>) => Promise<Name>;
    /**
     * Delete an existing name. Delete a name by its ID.
     *
     * @param request - The request {@link IpnsApiDeleteNameRequest}
     */
    deleteName: (request: Readonly<IpnsApiDeleteNameRequest>) => Promise<void>;
    protected pageOfListNames: (request?: Readonly<IpnsApiListNamesRequest>) => Promise<ListNamesResponse>;
    /**
     * List all names by a Project ID. Retrieve information about all names from a
     * Project ID.
     *
     * @param request - The request {@link IpnsApiListNamesRequest}
     * @returns A Promise of ListNamesResponse
     */
    listNames: (request?: Readonly<IpnsApiListNamesRequest>) => Promise<ListNamesResponse> & {
        all: () => Promise<Name[]>;
        [Symbol.asyncIterator]: () => AsyncGenerator<Name[], void, void>;
    };
    /**
     * Update name information. Update name information (CID, tag, name...).
     *
     * @param request - The request {@link IpnsApiUpdateNameRequest}
     * @returns A Promise of Name
     */
    updateName: (request: Readonly<IpnsApiUpdateNameRequest>) => Promise<Name>;
    /**
     * Export your private key. Export a private key by its ID.
     *
     * @param request - The request {@link IpnsApiExportKeyNameRequest}
     * @returns A Promise of ExportKeyNameResponse
     */
    exportKeyName: (request: Readonly<IpnsApiExportKeyNameRequest>) => Promise<ExportKeyNameResponse>;
    /**
     * Import your private key. Import a private key.
     *
     * @param request - The request {@link IpnsApiImportKeyNameRequest}
     * @returns A Promise of Name
     */
    importKeyName: (request: Readonly<IpnsApiImportKeyNameRequest>) => Promise<Name>;
}
