import "../../../client/dist/internal/logger/index.js";
import { isJSONObject } from "../../../client/dist/helpers/json.js";
import { unmarshalDate, unmarshalArrayOfObject, resolveOneOf } from "../../../client/dist/helpers/marshalling.js";
import "../../../client/dist/vendor/base64/index.js";
const unmarshalKeyRotationPolicy = (data) => {
  if (!isJSONObject(data)) {
    throw new TypeError(
      `Unmarshalling the type 'KeyRotationPolicy' failed as data isn't a dictionary.`
    );
  }
  return {
    nextRotationAt: unmarshalDate(data.next_rotation_at),
    rotationPeriod: data.rotation_period
  };
};
const unmarshalKeyUsage = (data) => {
  if (!isJSONObject(data)) {
    throw new TypeError(
      `Unmarshalling the type 'KeyUsage' failed as data isn't a dictionary.`
    );
  }
  return {
    symmetricEncryption: data.symmetric_encryption ? data.symmetric_encryption : void 0
  };
};
const unmarshalKey = (data) => {
  if (!isJSONObject(data)) {
    throw new TypeError(
      `Unmarshalling the type 'Key' failed as data isn't a dictionary.`
    );
  }
  return {
    createdAt: unmarshalDate(data.created_at),
    description: data.description,
    id: data.id,
    locked: data.locked,
    name: data.name,
    origin: data.origin,
    projectId: data.project_id,
    protected: data.protected,
    region: data.region,
    rotatedAt: unmarshalDate(data.rotated_at),
    rotationCount: data.rotation_count,
    rotationPolicy: data.rotation_policy ? unmarshalKeyRotationPolicy(data.rotation_policy) : void 0,
    state: data.state,
    tags: data.tags,
    updatedAt: unmarshalDate(data.updated_at),
    usage: data.usage ? unmarshalKeyUsage(data.usage) : void 0
  };
};
const unmarshalDataKey = (data) => {
  if (!isJSONObject(data)) {
    throw new TypeError(
      `Unmarshalling the type 'DataKey' failed as data isn't a dictionary.`
    );
  }
  return {
    algorithm: data.algorithm,
    ciphertext: data.ciphertext,
    createdAt: unmarshalDate(data.created_at),
    keyId: data.key_id,
    plaintext: data.plaintext
  };
};
const unmarshalDecryptResponse = (data) => {
  if (!isJSONObject(data)) {
    throw new TypeError(
      `Unmarshalling the type 'DecryptResponse' failed as data isn't a dictionary.`
    );
  }
  return {
    ciphertext: data.ciphertext,
    keyId: data.key_id,
    plaintext: data.plaintext
  };
};
const unmarshalEncryptResponse = (data) => {
  if (!isJSONObject(data)) {
    throw new TypeError(
      `Unmarshalling the type 'EncryptResponse' failed as data isn't a dictionary.`
    );
  }
  return {
    ciphertext: data.ciphertext,
    keyId: data.key_id
  };
};
const unmarshalListKeysResponse = (data) => {
  if (!isJSONObject(data)) {
    throw new TypeError(
      `Unmarshalling the type 'ListKeysResponse' failed as data isn't a dictionary.`
    );
  }
  return {
    keys: unmarshalArrayOfObject(data.keys, unmarshalKey),
    totalCount: data.total_count
  };
};
const marshalKeyRotationPolicy = (request, defaults) => ({
  next_rotation_at: request.nextRotationAt,
  rotation_period: request.rotationPeriod
});
const marshalKeyUsage = (request, defaults) => ({
  ...resolveOneOf([
    { param: "symmetric_encryption", value: request.symmetricEncryption }
  ])
});
const marshalCreateKeyRequest = (request, defaults) => ({
  description: request.description,
  name: request.name,
  origin: request.origin,
  project_id: request.projectId ?? defaults.defaultProjectId,
  rotation_policy: request.rotationPolicy !== void 0 ? marshalKeyRotationPolicy(request.rotationPolicy) : void 0,
  tags: request.tags,
  unprotected: request.unprotected,
  usage: request.usage !== void 0 ? marshalKeyUsage(request.usage) : void 0
});
const marshalDecryptRequest = (request, defaults) => ({
  associated_data: request.associatedData,
  ciphertext: request.ciphertext
});
const marshalEncryptRequest = (request, defaults) => ({
  associated_data: request.associatedData,
  plaintext: request.plaintext
});
const marshalGenerateDataKeyRequest = (request, defaults) => ({
  algorithm: request.algorithm,
  without_plaintext: request.withoutPlaintext
});
const marshalImportKeyMaterialRequest = (request, defaults) => ({
  key_material: request.keyMaterial,
  salt: request.salt
});
const marshalUpdateKeyRequest = (request, defaults) => ({
  description: request.description,
  name: request.name,
  rotation_policy: request.rotationPolicy !== void 0 ? marshalKeyRotationPolicy(request.rotationPolicy) : void 0,
  tags: request.tags
});
export {
  marshalCreateKeyRequest,
  marshalDecryptRequest,
  marshalEncryptRequest,
  marshalGenerateDataKeyRequest,
  marshalImportKeyMaterialRequest,
  marshalUpdateKeyRequest,
  unmarshalDataKey,
  unmarshalDecryptResponse,
  unmarshalEncryptResponse,
  unmarshalKey,
  unmarshalListKeysResponse
};
