import { API as ParentAPI } from '@scaleway/sdk-client';
import type { Region as ScwRegion, Zone as ScwZone, WaitForOptions } from '@scaleway/sdk-client';
import type { Acl, AddBackendServersRequest, AttachPrivateNetworkRequest, Backend, Certificate, CreateAclRequest, CreateBackendRequest, CreateCertificateRequest, CreateFrontendRequest, CreateIpRequest, CreateLbRequest, CreateRouteRequest, CreateSubscriberRequest, DeleteAclRequest, DeleteBackendRequest, DeleteCertificateRequest, DeleteFrontendRequest, DeleteLbRequest, DeleteRouteRequest, DeleteSubscriberRequest, DetachPrivateNetworkRequest, Frontend, GetAclRequest, GetBackendRequest, GetCertificateRequest, GetFrontendRequest, GetIpRequest, GetLbRequest, GetLbStatsRequest, GetRouteRequest, GetSubscriberRequest, HealthCheck, Ip, Lb, LbStats, ListAclResponse, ListAclsRequest, ListBackendStatsRequest, ListBackendStatsResponse, ListBackendsRequest, ListBackendsResponse, ListCertificatesRequest, ListCertificatesResponse, ListFrontendsRequest, ListFrontendsResponse, ListIPsRequest, ListIpsResponse, ListLbPrivateNetworksRequest, ListLbPrivateNetworksResponse, ListLbTypesRequest, ListLbTypesResponse, ListLbsRequest, ListLbsResponse, ListRoutesRequest, ListRoutesResponse, ListSubscriberRequest, ListSubscriberResponse, MigrateLbRequest, PrivateNetwork, ReleaseIpRequest, RemoveBackendServersRequest, Route, SetAclsResponse, SetBackendServersRequest, SubscribeToLbRequest, Subscriber, UnsubscribeFromLbRequest, UpdateAclRequest, UpdateBackendRequest, UpdateCertificateRequest, UpdateFrontendRequest, UpdateHealthCheckRequest, UpdateIpRequest, UpdateLbRequest, UpdateRouteRequest, UpdateSubscriberRequest, ZonedApiAddBackendServersRequest, ZonedApiAttachPrivateNetworkRequest, ZonedApiCreateAclRequest, ZonedApiCreateBackendRequest, ZonedApiCreateCertificateRequest, ZonedApiCreateFrontendRequest, ZonedApiCreateIpRequest, ZonedApiCreateLbRequest, ZonedApiCreateRouteRequest, ZonedApiCreateSubscriberRequest, ZonedApiDeleteAclRequest, ZonedApiDeleteBackendRequest, ZonedApiDeleteCertificateRequest, ZonedApiDeleteFrontendRequest, ZonedApiDeleteLbRequest, ZonedApiDeleteRouteRequest, ZonedApiDeleteSubscriberRequest, ZonedApiDetachPrivateNetworkRequest, ZonedApiGetAclRequest, ZonedApiGetBackendRequest, ZonedApiGetCertificateRequest, ZonedApiGetFrontendRequest, ZonedApiGetIpRequest, ZonedApiGetLbRequest, ZonedApiGetLbStatsRequest, ZonedApiGetRouteRequest, ZonedApiGetSubscriberRequest, ZonedApiListAclsRequest, ZonedApiListBackendStatsRequest, ZonedApiListBackendsRequest, ZonedApiListCertificatesRequest, ZonedApiListFrontendsRequest, ZonedApiListIPsRequest, ZonedApiListLbPrivateNetworksRequest, ZonedApiListLbTypesRequest, ZonedApiListLbsRequest, ZonedApiListRoutesRequest, ZonedApiListSubscriberRequest, ZonedApiMigrateLbRequest, ZonedApiReleaseIpRequest, ZonedApiRemoveBackendServersRequest, ZonedApiSetAclsRequest, ZonedApiSetBackendServersRequest, ZonedApiSubscribeToLbRequest, ZonedApiUnsubscribeFromLbRequest, ZonedApiUpdateAclRequest, ZonedApiUpdateBackendRequest, ZonedApiUpdateCertificateRequest, ZonedApiUpdateFrontendRequest, ZonedApiUpdateHealthCheckRequest, ZonedApiUpdateIpRequest, ZonedApiUpdateLbRequest, ZonedApiUpdateRouteRequest, ZonedApiUpdateSubscriberRequest } from './types.gen';
/**
 * Load Balancer API.

This API allows you to manage your Scaleway Load Balancer services.
 */
export declare class ZonedAPI extends ParentAPI {
    /** Lists the available zones of the API. */
    static readonly LOCALITIES: ScwZone[];
    protected pageOfListLbs: (request?: Readonly<ZonedApiListLbsRequest>) => Promise<ListLbsResponse>;
    /**
     * List Load Balancers. List all Load Balancers in the specified zone, for a Scaleway Organization or Scaleway Project. By default, the Load Balancers returned in the list are ordered by creation date in ascending order, though this can be modified via the `order_by` field.
     *
     * @param request - The request {@link ZonedApiListLbsRequest}
     * @returns A Promise of ListLbsResponse
     */
    listLbs: (request?: Readonly<ZonedApiListLbsRequest>) => Promise<ListLbsResponse> & {
        all: () => Promise<Lb[]>;
        [Symbol.asyncIterator]: () => AsyncGenerator<Lb[], void, void>;
    };
    /**
     * Create a Load Balancer. Create a new Load Balancer. Note that the Load Balancer will be created without frontends or backends; these must be created separately via the dedicated endpoints.
     *
     * @param request - The request {@link ZonedApiCreateLbRequest}
     * @returns A Promise of Lb
     */
    createLb: (request: Readonly<ZonedApiCreateLbRequest>) => Promise<Lb>;
    /**
     * Get a Load Balancer. Retrieve information about an existing Load Balancer, specified by its Load Balancer ID. Its full details, including name, status and IP address, are returned in the response object.
     *
     * @param request - The request {@link ZonedApiGetLbRequest}
     * @returns A Promise of Lb
     */
    getLb: (request: Readonly<ZonedApiGetLbRequest>) => Promise<Lb>;
    /**
     * Waits for {@link Lb} to be in a final state.
     *
     * @param request - The request {@link ZonedApiGetLbRequest}
     * @param options - The waiting options
     * @returns A Promise of Lb
     */
    waitForLb: (request: Readonly<ZonedApiGetLbRequest>, options?: Readonly<WaitForOptions<Lb>>) => Promise<Lb>;
    /**
     * Update a Load Balancer. Update the parameters of an existing Load Balancer, specified by its Load Balancer ID. Note that the request type is PUT and not PATCH. You must set all parameters.
     *
     * @param request - The request {@link ZonedApiUpdateLbRequest}
     * @returns A Promise of Lb
     */
    updateLb: (request: Readonly<ZonedApiUpdateLbRequest>) => Promise<Lb>;
    /**
     * Delete a Load Balancer. Delete an existing Load Balancer, specified by its Load Balancer ID. Deleting a Load Balancer is permanent, and cannot be undone. The Load Balancer's flexible IP address can either be deleted with the Load Balancer, or kept in your account for future use.
     *
     * @param request - The request {@link ZonedApiDeleteLbRequest}
     */
    deleteLb: (request: Readonly<ZonedApiDeleteLbRequest>) => Promise<void>;
    /**
     * Migrate a Load Balancer. Migrate an existing Load Balancer from one commercial type to another. Allows you to scale your Load Balancer up or down in terms of bandwidth or multi-cloud provision.
     *
     * @param request - The request {@link ZonedApiMigrateLbRequest}
     * @returns A Promise of Lb
     */
    migrateLb: (request: Readonly<ZonedApiMigrateLbRequest>) => Promise<Lb>;
    protected pageOfListIPs: (request?: Readonly<ZonedApiListIPsRequest>) => Promise<ListIpsResponse>;
    /**
     * List IP addresses. List the Load Balancer flexible IP addresses held in the account (filtered by Organization ID or Project ID). It is also possible to search for a specific IP address.
     *
     * @param request - The request {@link ZonedApiListIPsRequest}
     * @returns A Promise of ListIpsResponse
     */
    listIPs: (request?: Readonly<ZonedApiListIPsRequest>) => Promise<ListIpsResponse> & {
        all: () => Promise<Ip[]>;
        [Symbol.asyncIterator]: () => AsyncGenerator<Ip[], void, void>;
    };
    /**
     * Create an IP address. Create a new Load Balancer flexible IP address, in the specified Scaleway Project. This can be attached to new Load Balancers created in the future.
     *
     * @param request - The request {@link ZonedApiCreateIpRequest}
     * @returns A Promise of Ip
     */
    createIp: (request: Readonly<ZonedApiCreateIpRequest>) => Promise<Ip>;
    /**
     * Get an IP address. Retrieve the full details of a Load Balancer flexible IP address.
     *
     * @param request - The request {@link ZonedApiGetIpRequest}
     * @returns A Promise of Ip
     */
    getIp: (request: Readonly<ZonedApiGetIpRequest>) => Promise<Ip>;
    /**
     * Delete an IP address. Delete a Load Balancer flexible IP address. This action is irreversible, and cannot be undone.
     *
     * @param request - The request {@link ZonedApiReleaseIpRequest}
     */
    releaseIp: (request: Readonly<ZonedApiReleaseIpRequest>) => Promise<void>;
    /**
     * Update an IP address. Update the reverse DNS of a Load Balancer flexible IP address.
     *
     * @param request - The request {@link ZonedApiUpdateIpRequest}
     * @returns A Promise of Ip
     */
    updateIp: (request: Readonly<ZonedApiUpdateIpRequest>) => Promise<Ip>;
    protected pageOfListBackends: (request: Readonly<ZonedApiListBackendsRequest>) => Promise<ListBackendsResponse>;
    /**
     * List the backends of a given Load Balancer. List all the backends of a Load Balancer, specified by its Load Balancer ID. By default, results are returned in ascending order by the creation date of each backend. The response is an array of backend objects, containing full details of each one including their configuration parameters such as protocol, port and forwarding algorithm.
     *
     * @param request - The request {@link ZonedApiListBackendsRequest}
     * @returns A Promise of ListBackendsResponse
     */
    listBackends: (request: Readonly<ZonedApiListBackendsRequest>) => Promise<ListBackendsResponse> & {
        all: () => Promise<Backend[]>;
        [Symbol.asyncIterator]: () => AsyncGenerator<Backend[], void, void>;
    };
    /**
     * Create a backend for a given Load Balancer. Create a new backend for a given Load Balancer, specifying its full configuration including protocol, port and forwarding algorithm.
     *
     * @param request - The request {@link ZonedApiCreateBackendRequest}
     * @returns A Promise of Backend
     */
    createBackend: (request: Readonly<ZonedApiCreateBackendRequest>) => Promise<Backend>;
    /**
     * Get a backend of a given Load Balancer. Get the full details of a given backend, specified by its backend ID. The response contains the backend's full configuration parameters including protocol, port and forwarding algorithm.
     *
     * @param request - The request {@link ZonedApiGetBackendRequest}
     * @returns A Promise of Backend
     */
    getBackend: (request: Readonly<ZonedApiGetBackendRequest>) => Promise<Backend>;
    /**
     * Update a backend of a given Load Balancer. Update a backend of a given Load Balancer, specified by its backend ID. Note that the request type is PUT and not PATCH. You must set all parameters.
     *
     * @param request - The request {@link ZonedApiUpdateBackendRequest}
     * @returns A Promise of Backend
     */
    updateBackend: (request: Readonly<ZonedApiUpdateBackendRequest>) => Promise<Backend>;
    /**
     * Delete a backend of a given Load Balancer. Delete a backend of a given Load Balancer, specified by its backend ID. This action is irreversible and cannot be undone.
     *
     * @param request - The request {@link ZonedApiDeleteBackendRequest}
     */
    deleteBackend: (request: Readonly<ZonedApiDeleteBackendRequest>) => Promise<void>;
    /**
     * Add a set of backend servers to a given backend. For a given backend specified by its backend ID, add a set of backend servers (identified by their IP addresses) it should forward traffic to. These will be appended to any existing set of backend servers for this backend.
     *
     * @param request - The request {@link ZonedApiAddBackendServersRequest}
     * @returns A Promise of Backend
     */
    addBackendServers: (request: Readonly<ZonedApiAddBackendServersRequest>) => Promise<Backend>;
    /**
     * Remove a set of servers for a given backend. For a given backend specified by its backend ID, remove the specified backend servers (identified by their IP addresses) so that it no longer forwards traffic to them.
     *
     * @param request - The request {@link ZonedApiRemoveBackendServersRequest}
     * @returns A Promise of Backend
     */
    removeBackendServers: (request: Readonly<ZonedApiRemoveBackendServersRequest>) => Promise<Backend>;
    /**
     * Define all backend servers for a given backend. For a given backend specified by its backend ID, define the set of backend servers (identified by their IP addresses) that it should forward traffic to. Any existing backend servers configured for this backend will be removed.
     *
     * @param request - The request {@link ZonedApiSetBackendServersRequest}
     * @returns A Promise of Backend
     */
    setBackendServers: (request: Readonly<ZonedApiSetBackendServersRequest>) => Promise<Backend>;
    /**
     * Update a health check for a given backend. Update the configuration of the health check performed by a given backend to verify the health of its backend servers, identified by its backend ID. Note that the request type is PUT and not PATCH. You must set all parameters.
     *
     * @param request - The request {@link ZonedApiUpdateHealthCheckRequest}
     * @returns A Promise of HealthCheck
     */
    updateHealthCheck: (request: Readonly<ZonedApiUpdateHealthCheckRequest>) => Promise<HealthCheck>;
    protected pageOfListFrontends: (request: Readonly<ZonedApiListFrontendsRequest>) => Promise<ListFrontendsResponse>;
    /**
     * List frontends of a given Load Balancer. List all the frontends of a Load Balancer, specified by its Load Balancer ID. By default, results are returned in ascending order by the creation date of each frontend. The response is an array of frontend objects, containing full details of each one including the port they listen on and the backend they are attached to.
     *
     * @param request - The request {@link ZonedApiListFrontendsRequest}
     * @returns A Promise of ListFrontendsResponse
     */
    listFrontends: (request: Readonly<ZonedApiListFrontendsRequest>) => Promise<ListFrontendsResponse> & {
        all: () => Promise<Frontend[]>;
        [Symbol.asyncIterator]: () => AsyncGenerator<Frontend[], void, void>;
    };
    /**
     * Create a frontend in a given Load Balancer. Create a new frontend for a given Load Balancer, specifying its configuration including the port it should listen on and the backend to attach it to.
     *
     * @param request - The request {@link ZonedApiCreateFrontendRequest}
     * @returns A Promise of Frontend
     */
    createFrontend: (request: Readonly<ZonedApiCreateFrontendRequest>) => Promise<Frontend>;
    /**
     * Get a frontend. Get the full details of a given frontend, specified by its frontend ID. The response contains the frontend's full configuration parameters including the backend it is attached to, the port it listens on, and any certificates it has.
     *
     * @param request - The request {@link ZonedApiGetFrontendRequest}
     * @returns A Promise of Frontend
     */
    getFrontend: (request: Readonly<ZonedApiGetFrontendRequest>) => Promise<Frontend>;
    /**
     * Update a frontend. Update a given frontend, specified by its frontend ID. You can update configuration parameters including its name and the port it listens on. Note that the request type is PUT and not PATCH. You must set all parameters.
     *
     * @param request - The request {@link ZonedApiUpdateFrontendRequest}
     * @returns A Promise of Frontend
     */
    updateFrontend: (request: Readonly<ZonedApiUpdateFrontendRequest>) => Promise<Frontend>;
    /**
     * Delete a frontend. Delete a given frontend, specified by its frontend ID. This action is irreversible and cannot be undone.
     *
     * @param request - The request {@link ZonedApiDeleteFrontendRequest}
     */
    deleteFrontend: (request: Readonly<ZonedApiDeleteFrontendRequest>) => Promise<void>;
    protected pageOfListRoutes: (request?: Readonly<ZonedApiListRoutesRequest>) => Promise<ListRoutesResponse>;
    /**
     * List all routes. List all routes for a given frontend. The response is an array of routes, each one  with a specified backend to direct to if a certain condition is matched (based on the value of the SNI field or HTTP Host header).
     *
     * @param request - The request {@link ZonedApiListRoutesRequest}
     * @returns A Promise of ListRoutesResponse
     */
    listRoutes: (request?: Readonly<ZonedApiListRoutesRequest>) => Promise<ListRoutesResponse> & {
        all: () => Promise<Route[]>;
        [Symbol.asyncIterator]: () => AsyncGenerator<Route[], void, void>;
    };
    /**
     * Create a route. Create a new route on a given frontend. To configure a route, specify the backend to direct to if a certain condition is matched (based on the value of the SNI field or HTTP Host header).
     *
     * @param request - The request {@link ZonedApiCreateRouteRequest}
     * @returns A Promise of Route
     */
    createRoute: (request: Readonly<ZonedApiCreateRouteRequest>) => Promise<Route>;
    /**
     * Get a route. Retrieve information about an existing route, specified by its route ID. Its full details, origin frontend, target backend and match condition, are returned in the response object.
     *
     * @param request - The request {@link ZonedApiGetRouteRequest}
     * @returns A Promise of Route
     */
    getRoute: (request: Readonly<ZonedApiGetRouteRequest>) => Promise<Route>;
    /**
     * Update a route. Update the configuration of an existing route, specified by its route ID.
     *
     * @param request - The request {@link ZonedApiUpdateRouteRequest}
     * @returns A Promise of Route
     */
    updateRoute: (request: Readonly<ZonedApiUpdateRouteRequest>) => Promise<Route>;
    /**
     * Delete a route. Delete an existing route, specified by its route ID. Deleting a route is permanent, and cannot be undone.
     *
     * @param request - The request {@link ZonedApiDeleteRouteRequest}
     */
    deleteRoute: (request: Readonly<ZonedApiDeleteRouteRequest>) => Promise<void>;
    /**
     * Get usage statistics of a given Load Balancer.
     *
     * @deprecated
     * @param request - The request {@link ZonedApiGetLbStatsRequest}
     * @returns A Promise of LbStats
     */
    getLbStats: (request: Readonly<ZonedApiGetLbStatsRequest>) => Promise<LbStats>;
    protected pageOfListBackendStats: (request: Readonly<ZonedApiListBackendStatsRequest>) => Promise<ListBackendStatsResponse>;
    /**
     * List backend server statistics. List information about your backend servers, including their state and the result of their last health check.
     *
     * @param request - The request {@link ZonedApiListBackendStatsRequest}
     * @returns A Promise of ListBackendStatsResponse
     */
    listBackendStats: (request: Readonly<ZonedApiListBackendStatsRequest>) => Promise<ListBackendStatsResponse> & {
        all: () => Promise<import("./types.gen").BackendServerStats[]>;
        [Symbol.asyncIterator]: () => AsyncGenerator<import("./types.gen").BackendServerStats[], void, void>;
    };
    protected pageOfListAcls: (request: Readonly<ZonedApiListAclsRequest>) => Promise<ListAclResponse>;
    /**
     * List ACLs for a given frontend. List the ACLs for a given frontend, specified by its frontend ID. The response is an array of ACL objects, each one representing an ACL that denies or allows traffic based on certain conditions.
     *
     * @param request - The request {@link ZonedApiListAclsRequest}
     * @returns A Promise of ListAclResponse
     */
    listAcls: (request: Readonly<ZonedApiListAclsRequest>) => Promise<ListAclResponse> & {
        all: () => Promise<Acl[]>;
        [Symbol.asyncIterator]: () => AsyncGenerator<Acl[], void, void>;
    };
    /**
     * Create an ACL for a given frontend. Create a new ACL for a given frontend. Each ACL must have a name, an action to perform (allow or deny), and a match rule (the action is carried out when the incoming traffic matches the rule).
     *
     * @param request - The request {@link ZonedApiCreateAclRequest}
     * @returns A Promise of Acl
     */
    createAcl: (request: Readonly<ZonedApiCreateAclRequest>) => Promise<Acl>;
    /**
     * Get an ACL. Get information for a particular ACL, specified by its ACL ID. The response returns full details of the ACL, including its name, action, match rule and frontend.
     *
     * @param request - The request {@link ZonedApiGetAclRequest}
     * @returns A Promise of Acl
     */
    getAcl: (request: Readonly<ZonedApiGetAclRequest>) => Promise<Acl>;
    /**
     * Update an ACL. Update a particular ACL, specified by its ACL ID. You can update details including its name, action and match rule.
     *
     * @param request - The request {@link ZonedApiUpdateAclRequest}
     * @returns A Promise of Acl
     */
    updateAcl: (request: Readonly<ZonedApiUpdateAclRequest>) => Promise<Acl>;
    /**
     * Delete an ACL. Delete an ACL, specified by its ACL ID. Deleting an ACL is irreversible and cannot be undone.
     *
     * @param request - The request {@link ZonedApiDeleteAclRequest}
     */
    deleteAcl: (request: Readonly<ZonedApiDeleteAclRequest>) => Promise<void>;
    /**
     * Define all ACLs for a given frontend. For a given frontend specified by its frontend ID, define and add the complete set of ACLS for that frontend. Any existing ACLs on this frontend will be removed.
     *
     * @param request - The request {@link ZonedApiSetAclsRequest}
     * @returns A Promise of SetAclsResponse
     */
    setAcls: (request: Readonly<ZonedApiSetAclsRequest>) => Promise<SetAclsResponse>;
    /**
     * Create an SSL/TLS certificate. Generate a new SSL/TLS certificate for a given Load Balancer. You can choose to create a Let's Encrypt certificate, or import a custom certificate.
     *
     * @param request - The request {@link ZonedApiCreateCertificateRequest}
     * @returns A Promise of Certificate
     */
    createCertificate: (request: Readonly<ZonedApiCreateCertificateRequest>) => Promise<Certificate>;
    protected pageOfListCertificates: (request: Readonly<ZonedApiListCertificatesRequest>) => Promise<ListCertificatesResponse>;
    /**
     * List all SSL/TLS certificates on a given Load Balancer. List all the SSL/TLS certificates on a given Load Balancer. The response is an array of certificate objects, which are by default listed in ascending order of creation date.
     *
     * @param request - The request {@link ZonedApiListCertificatesRequest}
     * @returns A Promise of ListCertificatesResponse
     */
    listCertificates: (request: Readonly<ZonedApiListCertificatesRequest>) => Promise<ListCertificatesResponse> & {
        all: () => Promise<Certificate[]>;
        [Symbol.asyncIterator]: () => AsyncGenerator<Certificate[], void, void>;
    };
    /**
     * Get an SSL/TLS certificate. Get information for a particular SSL/TLS certificate, specified by its certificate ID. The response returns full details of the certificate, including its type, main domain name, and alternative domain names.
     *
     * @param request - The request {@link ZonedApiGetCertificateRequest}
     * @returns A Promise of Certificate
     */
    getCertificate: (request: Readonly<ZonedApiGetCertificateRequest>) => Promise<Certificate>;
    /**
     * Waits for {@link Certificate} to be in a final state.
     *
     * @param request - The request {@link ZonedApiGetCertificateRequest}
     * @param options - The waiting options
     * @returns A Promise of Certificate
     */
    waitForCertificate: (request: Readonly<ZonedApiGetCertificateRequest>, options?: Readonly<WaitForOptions<Certificate>>) => Promise<Certificate>;
    /**
     * Update an SSL/TLS certificate. Update the name of a particular SSL/TLS certificate, specified by its certificate ID.
     *
     * @param request - The request {@link ZonedApiUpdateCertificateRequest}
     * @returns A Promise of Certificate
     */
    updateCertificate: (request: Readonly<ZonedApiUpdateCertificateRequest>) => Promise<Certificate>;
    /**
     * Delete an SSL/TLS certificate. Delete an SSL/TLS certificate, specified by its certificate ID. Deleting a certificate is irreversible and cannot be undone.
     *
     * @param request - The request {@link ZonedApiDeleteCertificateRequest}
     */
    deleteCertificate: (request: Readonly<ZonedApiDeleteCertificateRequest>) => Promise<void>;
    protected pageOfListLbTypes: (request?: Readonly<ZonedApiListLbTypesRequest>) => Promise<ListLbTypesResponse>;
    /**
     * List all Load Balancer offer types. List all the different commercial Load Balancer types. The response includes an array of offer types, each with a name, description, and information about its stock availability.
     *
     * @param request - The request {@link ZonedApiListLbTypesRequest}
     * @returns A Promise of ListLbTypesResponse
     */
    listLbTypes: (request?: Readonly<ZonedApiListLbTypesRequest>) => Promise<ListLbTypesResponse> & {
        all: () => Promise<import("./types.gen").LbType[]>;
        [Symbol.asyncIterator]: () => AsyncGenerator<import("./types.gen").LbType[], void, void>;
    };
    /**
     * Create a subscriber. Create a new subscriber, either with an email configuration or a webhook configuration, for a specified Scaleway Project.
     *
     * @param request - The request {@link ZonedApiCreateSubscriberRequest}
     * @returns A Promise of Subscriber
     */
    createSubscriber: (request: Readonly<ZonedApiCreateSubscriberRequest>) => Promise<Subscriber>;
    /**
     * Get a subscriber. Retrieve information about an existing subscriber, specified by its subscriber ID. Its full details, including name and email/webhook configuration, are returned in the response object.
     *
     * @param request - The request {@link ZonedApiGetSubscriberRequest}
     * @returns A Promise of Subscriber
     */
    getSubscriber: (request: Readonly<ZonedApiGetSubscriberRequest>) => Promise<Subscriber>;
    protected pageOfListSubscriber: (request?: Readonly<ZonedApiListSubscriberRequest>) => Promise<ListSubscriberResponse>;
    /**
     * List all subscribers. List all subscribers to Load Balancer alerts. By default, returns all subscribers to Load Balancer alerts for the Organization associated with the authentication token used for the request.
     *
     * @param request - The request {@link ZonedApiListSubscriberRequest}
     * @returns A Promise of ListSubscriberResponse
     */
    listSubscriber: (request?: Readonly<ZonedApiListSubscriberRequest>) => Promise<ListSubscriberResponse> & {
        all: () => Promise<Subscriber[]>;
        [Symbol.asyncIterator]: () => AsyncGenerator<Subscriber[], void, void>;
    };
    /**
     * Update a subscriber. Update the parameters of a given subscriber (e.g. name, webhook configuration, email configuration), specified by its subscriber ID.
     *
     * @param request - The request {@link ZonedApiUpdateSubscriberRequest}
     * @returns A Promise of Subscriber
     */
    updateSubscriber: (request: Readonly<ZonedApiUpdateSubscriberRequest>) => Promise<Subscriber>;
    /**
     * Delete a subscriber. Delete an existing subscriber, specified by its subscriber ID. Deleting a subscriber is permanent, and cannot be undone.
     *
     * @param request - The request {@link ZonedApiDeleteSubscriberRequest}
     */
    deleteSubscriber: (request: Readonly<ZonedApiDeleteSubscriberRequest>) => Promise<void>;
    /**
     * Subscribe a subscriber to alerts for a given Load Balancer. Subscribe an existing subscriber to alerts for a given Load Balancer.
     *
     * @param request - The request {@link ZonedApiSubscribeToLbRequest}
     * @returns A Promise of Lb
     */
    subscribeToLb: (request: Readonly<ZonedApiSubscribeToLbRequest>) => Promise<Lb>;
    /**
     * Unsubscribe a subscriber from alerts for a given Load Balancer. Unsubscribe a subscriber from alerts for a given Load Balancer. The subscriber is not deleted, and can be resubscribed in the future if necessary.
     *
     * @param request - The request {@link ZonedApiUnsubscribeFromLbRequest}
     * @returns A Promise of Lb
     */
    unsubscribeFromLb: (request: Readonly<ZonedApiUnsubscribeFromLbRequest>) => Promise<Lb>;
    protected pageOfListLbPrivateNetworks: (request: Readonly<ZonedApiListLbPrivateNetworksRequest>) => Promise<ListLbPrivateNetworksResponse>;
    /**
     * List Private Networks attached to a Load Balancer. List the Private Networks attached to a given Load Balancer, specified by its Load Balancer ID. The response is an array of Private Network objects, giving information including the status, configuration, name and creation date of each Private Network.
     *
     * @param request - The request {@link ZonedApiListLbPrivateNetworksRequest}
     * @returns A Promise of ListLbPrivateNetworksResponse
     */
    listLbPrivateNetworks: (request: Readonly<ZonedApiListLbPrivateNetworksRequest>) => Promise<ListLbPrivateNetworksResponse> & {
        all: () => Promise<PrivateNetwork[]>;
        [Symbol.asyncIterator]: () => AsyncGenerator<PrivateNetwork[], void, void>;
    };
    /**
     * Attach a Load Balancer to a Private Network. Attach a specified Load Balancer to a specified Private Network, defining a static or DHCP configuration for the Load Balancer on the network.
     *
     * @param request - The request {@link ZonedApiAttachPrivateNetworkRequest}
     * @returns A Promise of PrivateNetwork
     */
    attachPrivateNetwork: (request: Readonly<ZonedApiAttachPrivateNetworkRequest>) => Promise<PrivateNetwork>;
    /**
     * Detach Load Balancer from Private Network. Detach a specified Load Balancer from a specified Private Network.
     *
     * @param request - The request {@link ZonedApiDetachPrivateNetworkRequest}
     */
    detachPrivateNetwork: (request: Readonly<ZonedApiDetachPrivateNetworkRequest>) => Promise<void>;
}
/**
 * Load balancer API.

This API allows you to manage your Load Balancers.
 */
export declare class API extends ParentAPI {
    /** Lists the available regions of the API. */
    static readonly LOCALITIES: ScwRegion[];
    protected pageOfListLbs: (request?: Readonly<ListLbsRequest>) => Promise<ListLbsResponse>;
    /**
     * List load balancers.
     *
     * @param request - The request {@link ListLbsRequest}
     * @returns A Promise of ListLbsResponse
     */
    listLbs: (request?: Readonly<ListLbsRequest>) => Promise<ListLbsResponse> & {
        all: () => Promise<Lb[]>;
        [Symbol.asyncIterator]: () => AsyncGenerator<Lb[], void, void>;
    };
    /**
     * Create a load balancer.
     *
     * @param request - The request {@link CreateLbRequest}
     * @returns A Promise of Lb
     */
    createLb: (request: Readonly<CreateLbRequest>) => Promise<Lb>;
    /**
     * Get a load balancer.
     *
     * @param request - The request {@link GetLbRequest}
     * @returns A Promise of Lb
     */
    getLb: (request: Readonly<GetLbRequest>) => Promise<Lb>;
    /**
     * Waits for {@link Lb} to be in a final state.
     *
     * @param request - The request {@link GetLbRequest}
     * @param options - The waiting options
     * @returns A Promise of Lb
     */
    waitForLb: (request: Readonly<GetLbRequest>, options?: Readonly<WaitForOptions<Lb>>) => Promise<Lb>;
    /**
     * Update a load balancer.
     *
     * @param request - The request {@link UpdateLbRequest}
     * @returns A Promise of Lb
     */
    updateLb: (request: Readonly<UpdateLbRequest>) => Promise<Lb>;
    /**
     * Delete a load balancer.
     *
     * @param request - The request {@link DeleteLbRequest}
     */
    deleteLb: (request: Readonly<DeleteLbRequest>) => Promise<void>;
    /**
     * Migrate a load balancer.
     *
     * @param request - The request {@link MigrateLbRequest}
     * @returns A Promise of Lb
     */
    migrateLb: (request: Readonly<MigrateLbRequest>) => Promise<Lb>;
    protected pageOfListIPs: (request?: Readonly<ListIPsRequest>) => Promise<ListIpsResponse>;
    /**
     * List IPs.
     *
     * @param request - The request {@link ListIPsRequest}
     * @returns A Promise of ListIpsResponse
     */
    listIPs: (request?: Readonly<ListIPsRequest>) => Promise<ListIpsResponse> & {
        all: () => Promise<Ip[]>;
        [Symbol.asyncIterator]: () => AsyncGenerator<Ip[], void, void>;
    };
    /**
     * Create an IP.
     *
     * @param request - The request {@link CreateIpRequest}
     * @returns A Promise of Ip
     */
    createIp: (request: Readonly<CreateIpRequest>) => Promise<Ip>;
    /**
     * Get an IP.
     *
     * @param request - The request {@link GetIpRequest}
     * @returns A Promise of Ip
     */
    getIp: (request: Readonly<GetIpRequest>) => Promise<Ip>;
    /**
     * Delete an IP.
     *
     * @param request - The request {@link ReleaseIpRequest}
     */
    releaseIp: (request: Readonly<ReleaseIpRequest>) => Promise<void>;
    /**
     * Update an IP.
     *
     * @param request - The request {@link UpdateIpRequest}
     * @returns A Promise of Ip
     */
    updateIp: (request: Readonly<UpdateIpRequest>) => Promise<Ip>;
    protected pageOfListBackends: (request: Readonly<ListBackendsRequest>) => Promise<ListBackendsResponse>;
    /**
     * List backends in a given load balancer.
     *
     * @param request - The request {@link ListBackendsRequest}
     * @returns A Promise of ListBackendsResponse
     */
    listBackends: (request: Readonly<ListBackendsRequest>) => Promise<ListBackendsResponse> & {
        all: () => Promise<Backend[]>;
        [Symbol.asyncIterator]: () => AsyncGenerator<Backend[], void, void>;
    };
    /**
     * Create a backend in a given load balancer.
     *
     * @param request - The request {@link CreateBackendRequest}
     * @returns A Promise of Backend
     */
    createBackend: (request: Readonly<CreateBackendRequest>) => Promise<Backend>;
    /**
     * Get a backend in a given load balancer.
     *
     * @param request - The request {@link GetBackendRequest}
     * @returns A Promise of Backend
     */
    getBackend: (request: Readonly<GetBackendRequest>) => Promise<Backend>;
    /**
     * Update a backend in a given load balancer.
     *
     * @param request - The request {@link UpdateBackendRequest}
     * @returns A Promise of Backend
     */
    updateBackend: (request: Readonly<UpdateBackendRequest>) => Promise<Backend>;
    /**
     * Delete a backend in a given load balancer.
     *
     * @param request - The request {@link DeleteBackendRequest}
     */
    deleteBackend: (request: Readonly<DeleteBackendRequest>) => Promise<void>;
    /**
     * Add a set of servers in a given backend.
     *
     * @param request - The request {@link AddBackendServersRequest}
     * @returns A Promise of Backend
     */
    addBackendServers: (request: Readonly<AddBackendServersRequest>) => Promise<Backend>;
    /**
     * Remove a set of servers for a given backend.
     *
     * @param request - The request {@link RemoveBackendServersRequest}
     * @returns A Promise of Backend
     */
    removeBackendServers: (request: Readonly<RemoveBackendServersRequest>) => Promise<Backend>;
    /**
     * Define all servers in a given backend.
     *
     * @param request - The request {@link SetBackendServersRequest}
     * @returns A Promise of Backend
     */
    setBackendServers: (request: Readonly<SetBackendServersRequest>) => Promise<Backend>;
    /**
     * Update an health check for a given backend.
     *
     * @param request - The request {@link UpdateHealthCheckRequest}
     * @returns A Promise of HealthCheck
     */
    updateHealthCheck: (request: Readonly<UpdateHealthCheckRequest>) => Promise<HealthCheck>;
    protected pageOfListFrontends: (request: Readonly<ListFrontendsRequest>) => Promise<ListFrontendsResponse>;
    /**
     * List frontends in a given load balancer.
     *
     * @param request - The request {@link ListFrontendsRequest}
     * @returns A Promise of ListFrontendsResponse
     */
    listFrontends: (request: Readonly<ListFrontendsRequest>) => Promise<ListFrontendsResponse> & {
        all: () => Promise<Frontend[]>;
        [Symbol.asyncIterator]: () => AsyncGenerator<Frontend[], void, void>;
    };
    /**
     * Create a frontend in a given load balancer.
     *
     * @param request - The request {@link CreateFrontendRequest}
     * @returns A Promise of Frontend
     */
    createFrontend: (request: Readonly<CreateFrontendRequest>) => Promise<Frontend>;
    /**
     * Get a frontend.
     *
     * @param request - The request {@link GetFrontendRequest}
     * @returns A Promise of Frontend
     */
    getFrontend: (request: Readonly<GetFrontendRequest>) => Promise<Frontend>;
    /**
     * Update a frontend.
     *
     * @param request - The request {@link UpdateFrontendRequest}
     * @returns A Promise of Frontend
     */
    updateFrontend: (request: Readonly<UpdateFrontendRequest>) => Promise<Frontend>;
    /**
     * Delete a frontend.
     *
     * @param request - The request {@link DeleteFrontendRequest}
     */
    deleteFrontend: (request: Readonly<DeleteFrontendRequest>) => Promise<void>;
    protected pageOfListRoutes: (request?: Readonly<ListRoutesRequest>) => Promise<ListRoutesResponse>;
    /**
     * List all backend redirections.
     *
     * @param request - The request {@link ListRoutesRequest}
     * @returns A Promise of ListRoutesResponse
     */
    listRoutes: (request?: Readonly<ListRoutesRequest>) => Promise<ListRoutesResponse> & {
        all: () => Promise<Route[]>;
        [Symbol.asyncIterator]: () => AsyncGenerator<Route[], void, void>;
    };
    /**
     * Create a backend redirection.
     *
     * @param request - The request {@link CreateRouteRequest}
     * @returns A Promise of Route
     */
    createRoute: (request: Readonly<CreateRouteRequest>) => Promise<Route>;
    /**
     * Get single backend redirection.
     *
     * @param request - The request {@link GetRouteRequest}
     * @returns A Promise of Route
     */
    getRoute: (request: Readonly<GetRouteRequest>) => Promise<Route>;
    /**
     * Edit a backend redirection.
     *
     * @param request - The request {@link UpdateRouteRequest}
     * @returns A Promise of Route
     */
    updateRoute: (request: Readonly<UpdateRouteRequest>) => Promise<Route>;
    /**
     * Delete a backend redirection.
     *
     * @param request - The request {@link DeleteRouteRequest}
     */
    deleteRoute: (request: Readonly<DeleteRouteRequest>) => Promise<void>;
    /**
     * Get usage statistics of a given load balancer.
     *
     * @deprecated
     * @param request - The request {@link GetLbStatsRequest}
     * @returns A Promise of LbStats
     */
    getLbStats: (request: Readonly<GetLbStatsRequest>) => Promise<LbStats>;
    protected pageOfListBackendStats: (request: Readonly<ListBackendStatsRequest>) => Promise<ListBackendStatsResponse>;
    /**
     * List backend server statistics.
     *
     * @param request - The request {@link ListBackendStatsRequest}
     * @returns A Promise of ListBackendStatsResponse
     */
    listBackendStats: (request: Readonly<ListBackendStatsRequest>) => Promise<ListBackendStatsResponse> & {
        all: () => Promise<import("./types.gen").BackendServerStats[]>;
        [Symbol.asyncIterator]: () => AsyncGenerator<import("./types.gen").BackendServerStats[], void, void>;
    };
    protected pageOfListAcls: (request: Readonly<ListAclsRequest>) => Promise<ListAclResponse>;
    /**
     * List ACL for a given frontend.
     *
     * @param request - The request {@link ListAclsRequest}
     * @returns A Promise of ListAclResponse
     */
    listAcls: (request: Readonly<ListAclsRequest>) => Promise<ListAclResponse> & {
        all: () => Promise<Acl[]>;
        [Symbol.asyncIterator]: () => AsyncGenerator<Acl[], void, void>;
    };
    /**
     * Create an ACL for a given frontend.
     *
     * @param request - The request {@link CreateAclRequest}
     * @returns A Promise of Acl
     */
    createAcl: (request: Readonly<CreateAclRequest>) => Promise<Acl>;
    /**
     * Get an ACL.
     *
     * @param request - The request {@link GetAclRequest}
     * @returns A Promise of Acl
     */
    getAcl: (request: Readonly<GetAclRequest>) => Promise<Acl>;
    /**
     * Update an ACL.
     *
     * @param request - The request {@link UpdateAclRequest}
     * @returns A Promise of Acl
     */
    updateAcl: (request: Readonly<UpdateAclRequest>) => Promise<Acl>;
    /**
     * Delete an ACL.
     *
     * @param request - The request {@link DeleteAclRequest}
     */
    deleteAcl: (request: Readonly<DeleteAclRequest>) => Promise<void>;
    /**
     * Create a TLS certificate. Generate a new TLS certificate using Let's Encrypt or import your certificate.
     *
     * @param request - The request {@link CreateCertificateRequest}
     * @returns A Promise of Certificate
     */
    createCertificate: (request: Readonly<CreateCertificateRequest>) => Promise<Certificate>;
    protected pageOfListCertificates: (request: Readonly<ListCertificatesRequest>) => Promise<ListCertificatesResponse>;
    /**
     * List all TLS certificates on a given load balancer.
     *
     * @param request - The request {@link ListCertificatesRequest}
     * @returns A Promise of ListCertificatesResponse
     */
    listCertificates: (request: Readonly<ListCertificatesRequest>) => Promise<ListCertificatesResponse> & {
        all: () => Promise<Certificate[]>;
        [Symbol.asyncIterator]: () => AsyncGenerator<Certificate[], void, void>;
    };
    /**
     * Get a TLS certificate.
     *
     * @param request - The request {@link GetCertificateRequest}
     * @returns A Promise of Certificate
     */
    getCertificate: (request: Readonly<GetCertificateRequest>) => Promise<Certificate>;
    /**
     * Waits for {@link Certificate} to be in a final state.
     *
     * @param request - The request {@link GetCertificateRequest}
     * @param options - The waiting options
     * @returns A Promise of Certificate
     */
    waitForCertificate: (request: Readonly<GetCertificateRequest>, options?: Readonly<WaitForOptions<Certificate>>) => Promise<Certificate>;
    /**
     * Update a TLS certificate.
     *
     * @param request - The request {@link UpdateCertificateRequest}
     * @returns A Promise of Certificate
     */
    updateCertificate: (request: Readonly<UpdateCertificateRequest>) => Promise<Certificate>;
    /**
     * Delete a TLS certificate.
     *
     * @param request - The request {@link DeleteCertificateRequest}
     */
    deleteCertificate: (request: Readonly<DeleteCertificateRequest>) => Promise<void>;
    protected pageOfListLbTypes: (request?: Readonly<ListLbTypesRequest>) => Promise<ListLbTypesResponse>;
    /**
     * List all load balancer offer type.
     *
     * @param request - The request {@link ListLbTypesRequest}
     * @returns A Promise of ListLbTypesResponse
     */
    listLbTypes: (request?: Readonly<ListLbTypesRequest>) => Promise<ListLbTypesResponse> & {
        all: () => Promise<import("./types.gen").LbType[]>;
        [Symbol.asyncIterator]: () => AsyncGenerator<import("./types.gen").LbType[], void, void>;
    };
    /**
     * Create a subscriber, webhook or email.
     *
     * @param request - The request {@link CreateSubscriberRequest}
     * @returns A Promise of Subscriber
     */
    createSubscriber: (request: Readonly<CreateSubscriberRequest>) => Promise<Subscriber>;
    /**
     * Get a subscriber.
     *
     * @param request - The request {@link GetSubscriberRequest}
     * @returns A Promise of Subscriber
     */
    getSubscriber: (request: Readonly<GetSubscriberRequest>) => Promise<Subscriber>;
    protected pageOfListSubscriber: (request?: Readonly<ListSubscriberRequest>) => Promise<ListSubscriberResponse>;
    /**
     * List all subscriber.
     *
     * @param request - The request {@link ListSubscriberRequest}
     * @returns A Promise of ListSubscriberResponse
     */
    listSubscriber: (request?: Readonly<ListSubscriberRequest>) => Promise<ListSubscriberResponse> & {
        all: () => Promise<Subscriber[]>;
        [Symbol.asyncIterator]: () => AsyncGenerator<Subscriber[], void, void>;
    };
    /**
     * Update a subscriber.
     *
     * @param request - The request {@link UpdateSubscriberRequest}
     * @returns A Promise of Subscriber
     */
    updateSubscriber: (request: Readonly<UpdateSubscriberRequest>) => Promise<Subscriber>;
    /**
     * Delete a subscriber.
     *
     * @param request - The request {@link DeleteSubscriberRequest}
     */
    deleteSubscriber: (request: Readonly<DeleteSubscriberRequest>) => Promise<void>;
    /**
     * Subscribe a subscriber to a given load balancer.
     *
     * @param request - The request {@link SubscribeToLbRequest}
     * @returns A Promise of Lb
     */
    subscribeToLb: (request: Readonly<SubscribeToLbRequest>) => Promise<Lb>;
    /**
     * Unsubscribe a subscriber from a given load balancer.
     *
     * @param request - The request {@link UnsubscribeFromLbRequest}
     * @returns A Promise of Lb
     */
    unsubscribeFromLb: (request: Readonly<UnsubscribeFromLbRequest>) => Promise<Lb>;
    protected pageOfListLbPrivateNetworks: (request: Readonly<ListLbPrivateNetworksRequest>) => Promise<ListLbPrivateNetworksResponse>;
    /**
     * List attached private network of load balancer.
     *
     * @param request - The request {@link ListLbPrivateNetworksRequest}
     * @returns A Promise of ListLbPrivateNetworksResponse
     */
    listLbPrivateNetworks: (request: Readonly<ListLbPrivateNetworksRequest>) => Promise<ListLbPrivateNetworksResponse> & {
        all: () => Promise<PrivateNetwork[]>;
        [Symbol.asyncIterator]: () => AsyncGenerator<PrivateNetwork[], void, void>;
    };
    /**
     * Add load balancer on instance private network.
     *
     * @param request - The request {@link AttachPrivateNetworkRequest}
     * @returns A Promise of PrivateNetwork
     */
    attachPrivateNetwork: (request: Readonly<AttachPrivateNetworkRequest>) => Promise<PrivateNetwork>;
    /**
     * Remove load balancer of private network.
     *
     * @param request - The request {@link DetachPrivateNetworkRequest}
     */
    detachPrivateNetwork: (request: Readonly<DetachPrivateNetworkRequest>) => Promise<void>;
}
