import type { WaitForOptions } from '@scaleway/sdk-client';
import { API, ZonedAPI } from './api.gen.js';
import type { GetLbRequest, Lb, ListLbPrivateNetworksResponse, PrivateNetwork } from './types.gen';
import type { WaitForLbPrivateNetworksRequest, ZonedWaitForLbPrivateNetworksRequest } from './types.utils';
export declare class LbV1UtilsAPI extends API {
    /**
     * Waits for all private networks of a load balancer to be in a final state.
     *
     * @param request - The request {@link WaitForLbPrivateNetworksRequest}
     * @param options - The waiting options
     * @returns A Promise of ListLbPrivateNetworksResponse
     */
    waitForLbPrivateNetworks: (request: Readonly<WaitForLbPrivateNetworksRequest>, options?: Readonly<WaitForOptions<PrivateNetwork>>) => Promise<ListLbPrivateNetworksResponse>;
    /**
     * Waits for all instances of a load balancer to be in a final state.
     *
     * @param request - The request {@link GetLbRequest}
     * @param options - The waiting options
     * @returns A Promise of Lb
     */
    waitForLbInstances: (request: Readonly<GetLbRequest>, options?: Readonly<WaitForOptions<Lb>>) => Promise<Lb>;
}
export declare class LbZonedV1UtilsAPI extends ZonedAPI {
    /**
     * Waits for all private networks of a (zoned) load balancer to be in a final
     * state.
     *
     * @param request - The request {@link ZonedWaitForLbPrivateNetworksRequest}
     * @param options - The waiting options
     * @returns A Promise of ListLbPrivateNetworksResponse
     */
    waitForLbPrivateNetworks: (request: Readonly<ZonedWaitForLbPrivateNetworksRequest>, options?: Readonly<WaitForOptions<ListLbPrivateNetworksResponse>>) => Promise<ListLbPrivateNetworksResponse>;
    /**
     * Waits for all instances of a (zoned) load balancer to be in a final state.
     *
     * @param request - The request {@link GetLbRequest}
     * @param options - The waiting options
     * @returns A Promise of Lb
     */
    waitForLbInstances: (request: Readonly<GetLbRequest>, options?: Readonly<WaitForOptions<Lb>>) => Promise<Lb>;
}
