"use strict";
Object.defineProperty(exports, Symbol.toStringTag, { value: "Module" });
const randomName = require("@scaleway/random-name");
require("../../../client/dist/internal/logger/index.cjs");
const json = require("../../../client/dist/helpers/json.cjs");
const marshalling = require("../../../client/dist/helpers/marshalling.cjs");
require("../../../client/dist/vendor/base64/index.cjs");
const unmarshalEndpointPrivateNetworkDetails = (data) => {
  if (!json.isJSONObject(data)) {
    throw new TypeError(
      `Unmarshalling the type 'EndpointPrivateNetworkDetails' failed as data isn't a dictionary.`
    );
  }
  return {
    privateNetworkId: data.private_network_id
  };
};
const unmarshalEndpointPublicDetails = (data) => {
  if (!json.isJSONObject(data)) {
    throw new TypeError(
      `Unmarshalling the type 'EndpointPublicDetails' failed as data isn't a dictionary.`
    );
  }
  return {};
};
const unmarshalEndpoint = (data) => {
  if (!json.isJSONObject(data)) {
    throw new TypeError(
      `Unmarshalling the type 'Endpoint' failed as data isn't a dictionary.`
    );
  }
  return {
    dnsRecords: data.dns_records,
    id: data.id,
    ips: data.ips,
    port: data.port,
    privateNetwork: data.private_network ? unmarshalEndpointPrivateNetworkDetails(data.private_network) : void 0,
    public: data.public ? unmarshalEndpointPublicDetails(data.public) : void 0
  };
};
const unmarshalInstanceSetting = (data) => {
  if (!json.isJSONObject(data)) {
    throw new TypeError(
      `Unmarshalling the type 'InstanceSetting' failed as data isn't a dictionary.`
    );
  }
  return {
    name: data.name,
    value: data.value
  };
};
const unmarshalVolume = (data) => {
  if (!json.isJSONObject(data)) {
    throw new TypeError(
      `Unmarshalling the type 'Volume' failed as data isn't a dictionary.`
    );
  }
  return {
    size: data.size,
    type: data.type
  };
};
const unmarshalInstance = (data) => {
  if (!json.isJSONObject(data)) {
    throw new TypeError(
      `Unmarshalling the type 'Instance' failed as data isn't a dictionary.`
    );
  }
  return {
    createdAt: marshalling.unmarshalDate(data.created_at),
    endpoints: marshalling.unmarshalArrayOfObject(data.endpoints, unmarshalEndpoint),
    id: data.id,
    name: data.name,
    nodeNumber: data.node_number,
    nodeType: data.node_type,
    projectId: data.project_id,
    region: data.region,
    settings: marshalling.unmarshalArrayOfObject(data.settings, unmarshalInstanceSetting),
    status: data.status,
    tags: data.tags,
    version: data.version,
    volume: data.volume ? unmarshalVolume(data.volume) : void 0
  };
};
const unmarshalSnapshotVolumeType = (data) => {
  if (!json.isJSONObject(data)) {
    throw new TypeError(
      `Unmarshalling the type 'SnapshotVolumeType' failed as data isn't a dictionary.`
    );
  }
  return {
    type: data.type
  };
};
const unmarshalSnapshot = (data) => {
  if (!json.isJSONObject(data)) {
    throw new TypeError(
      `Unmarshalling the type 'Snapshot' failed as data isn't a dictionary.`
    );
  }
  return {
    createdAt: marshalling.unmarshalDate(data.created_at),
    expiresAt: marshalling.unmarshalDate(data.expires_at),
    id: data.id,
    instanceId: data.instance_id,
    instanceName: data.instance_name,
    name: data.name,
    nodeType: data.node_type,
    region: data.region,
    size: data.size,
    status: data.status,
    updatedAt: marshalling.unmarshalDate(data.updated_at),
    volumeType: data.volume_type ? unmarshalSnapshotVolumeType(data.volume_type) : void 0
  };
};
const unmarshalUserRole = (data) => {
  if (!json.isJSONObject(data)) {
    throw new TypeError(
      `Unmarshalling the type 'UserRole' failed as data isn't a dictionary.`
    );
  }
  return {
    anyDatabase: data.any_database,
    database: data.database,
    role: data.role
  };
};
const unmarshalUser = (data) => {
  if (!json.isJSONObject(data)) {
    throw new TypeError(
      `Unmarshalling the type 'User' failed as data isn't a dictionary.`
    );
  }
  return {
    name: data.name,
    roles: marshalling.unmarshalArrayOfObject(data.roles, unmarshalUserRole)
  };
};
const unmarshalListInstancesResponse = (data) => {
  if (!json.isJSONObject(data)) {
    throw new TypeError(
      `Unmarshalling the type 'ListInstancesResponse' failed as data isn't a dictionary.`
    );
  }
  return {
    instances: marshalling.unmarshalArrayOfObject(data.instances, unmarshalInstance),
    totalCount: data.total_count
  };
};
const unmarshalNodeTypeVolumeType = (data) => {
  if (!json.isJSONObject(data)) {
    throw new TypeError(
      `Unmarshalling the type 'NodeTypeVolumeType' failed as data isn't a dictionary.`
    );
  }
  return {
    chunkSize: data.chunk_size,
    description: data.description,
    maxSize: data.max_size,
    minSize: data.min_size,
    type: data.type
  };
};
const unmarshalNodeType = (data) => {
  if (!json.isJSONObject(data)) {
    throw new TypeError(
      `Unmarshalling the type 'NodeType' failed as data isn't a dictionary.`
    );
  }
  return {
    availableVolumeTypes: marshalling.unmarshalArrayOfObject(
      data.available_volume_types,
      unmarshalNodeTypeVolumeType
    ),
    beta: data.beta,
    description: data.description,
    disabled: data.disabled,
    instanceRange: data.instance_range,
    memory: data.memory,
    name: data.name,
    stockStatus: data.stock_status,
    vcpus: data.vcpus
  };
};
const unmarshalListNodeTypesResponse = (data) => {
  if (!json.isJSONObject(data)) {
    throw new TypeError(
      `Unmarshalling the type 'ListNodeTypesResponse' failed as data isn't a dictionary.`
    );
  }
  return {
    nodeTypes: marshalling.unmarshalArrayOfObject(data.node_types, unmarshalNodeType),
    totalCount: data.total_count
  };
};
const unmarshalListSnapshotsResponse = (data) => {
  if (!json.isJSONObject(data)) {
    throw new TypeError(
      `Unmarshalling the type 'ListSnapshotsResponse' failed as data isn't a dictionary.`
    );
  }
  return {
    snapshots: marshalling.unmarshalArrayOfObject(data.snapshots, unmarshalSnapshot),
    totalCount: data.total_count
  };
};
const unmarshalListUsersResponse = (data) => {
  if (!json.isJSONObject(data)) {
    throw new TypeError(
      `Unmarshalling the type 'ListUsersResponse' failed as data isn't a dictionary.`
    );
  }
  return {
    totalCount: data.total_count,
    users: marshalling.unmarshalArrayOfObject(data.users, unmarshalUser)
  };
};
const unmarshalSetting = (data) => {
  if (!json.isJSONObject(data)) {
    throw new TypeError(
      `Unmarshalling the type 'Setting' failed as data isn't a dictionary.`
    );
  }
  return {
    defaultValue: data.default_value,
    description: data.description,
    floatMax: data.float_max,
    floatMin: data.float_min,
    hotConfigurable: data.hot_configurable,
    intMax: data.int_max,
    intMin: data.int_min,
    name: data.name,
    propertyType: data.property_type,
    stringConstraint: data.string_constraint,
    unit: data.unit
  };
};
const unmarshalVersion = (data) => {
  if (!json.isJSONObject(data)) {
    throw new TypeError(
      `Unmarshalling the type 'Version' failed as data isn't a dictionary.`
    );
  }
  return {
    availableSettings: marshalling.unmarshalArrayOfObject(
      data.available_settings,
      unmarshalSetting
    ),
    endOfLifeAt: marshalling.unmarshalDate(data.end_of_life_at),
    version: data.version
  };
};
const unmarshalListVersionsResponse = (data) => {
  if (!json.isJSONObject(data)) {
    throw new TypeError(
      `Unmarshalling the type 'ListVersionsResponse' failed as data isn't a dictionary.`
    );
  }
  return {
    totalCount: data.total_count,
    versions: marshalling.unmarshalArrayOfObject(data.versions, unmarshalVersion)
  };
};
const marshalEndpointSpecPrivateNetworkDetails = (request, defaults) => ({
  private_network_id: request.privateNetworkId
});
const marshalEndpointSpecPublicDetails = (request, defaults) => ({});
const marshalEndpointSpec = (request, defaults) => ({
  ...marshalling.resolveOneOf([
    {
      param: "public",
      value: request.public !== void 0 ? marshalEndpointSpecPublicDetails(request.public) : void 0
    },
    {
      param: "private_network",
      value: request.privateNetwork !== void 0 ? marshalEndpointSpecPrivateNetworkDetails(
        request.privateNetwork
      ) : void 0
    }
  ])
});
const marshalCreateEndpointRequest = (request, defaults) => ({
  endpoint: marshalEndpointSpec(request.endpoint),
  instance_id: request.instanceId
});
const marshalCreateInstanceRequestVolumeDetails = (request, defaults) => ({
  volume_size: request.volumeSize,
  volume_type: request.volumeType
});
const marshalCreateInstanceRequest = (request, defaults) => ({
  endpoints: request.endpoints !== void 0 ? request.endpoints.map((elt) => marshalEndpointSpec(elt)) : void 0,
  name: request.name || randomName("mgdb"),
  node_number: request.nodeNumber,
  node_type: request.nodeType,
  password: request.password,
  project_id: request.projectId ?? defaults.defaultProjectId,
  tags: request.tags,
  user_name: request.userName,
  version: request.version,
  volume: request.volume !== void 0 ? marshalCreateInstanceRequestVolumeDetails(request.volume) : void 0
});
const marshalCreateSnapshotRequest = (request, defaults) => ({
  expires_at: request.expiresAt,
  name: request.name
});
const marshalCreateUserRequest = (request, defaults) => ({
  name: request.name,
  password: request.password
});
const marshalRestoreSnapshotRequestVolumeDetails = (request, defaults) => ({
  volume_type: request.volumeType
});
const marshalRestoreSnapshotRequest = (request, defaults) => ({
  instance_name: request.instanceName,
  node_number: request.nodeNumber,
  node_type: request.nodeType,
  volume: marshalRestoreSnapshotRequestVolumeDetails(request.volume)
});
const marshalUserRole = (request, defaults) => ({
  role: request.role,
  ...marshalling.resolveOneOf([
    { param: "database", value: request.database },
    { param: "any_database", value: request.anyDatabase }
  ])
});
const marshalSetUserRoleRequest = (request, defaults) => ({
  roles: request.roles !== void 0 ? request.roles.map((elt) => marshalUserRole(elt)) : void 0,
  user_name: request.userName
});
const marshalUpdateInstanceRequest = (request, defaults) => ({
  name: request.name,
  tags: request.tags
});
const marshalUpdateSnapshotRequest = (request, defaults) => ({
  expires_at: request.expiresAt,
  name: request.name
});
const marshalUpdateUserRequest = (request, defaults) => ({
  password: request.password
});
const marshalUpgradeInstanceRequest = (request, defaults) => ({
  ...marshalling.resolveOneOf([{ param: "volume_size", value: request.volumeSize }])
});
exports.marshalCreateEndpointRequest = marshalCreateEndpointRequest;
exports.marshalCreateInstanceRequest = marshalCreateInstanceRequest;
exports.marshalCreateSnapshotRequest = marshalCreateSnapshotRequest;
exports.marshalCreateUserRequest = marshalCreateUserRequest;
exports.marshalRestoreSnapshotRequest = marshalRestoreSnapshotRequest;
exports.marshalSetUserRoleRequest = marshalSetUserRoleRequest;
exports.marshalUpdateInstanceRequest = marshalUpdateInstanceRequest;
exports.marshalUpdateSnapshotRequest = marshalUpdateSnapshotRequest;
exports.marshalUpdateUserRequest = marshalUpdateUserRequest;
exports.marshalUpgradeInstanceRequest = marshalUpgradeInstanceRequest;
exports.unmarshalEndpoint = unmarshalEndpoint;
exports.unmarshalInstance = unmarshalInstance;
exports.unmarshalInstanceSetting = unmarshalInstanceSetting;
exports.unmarshalListInstancesResponse = unmarshalListInstancesResponse;
exports.unmarshalListNodeTypesResponse = unmarshalListNodeTypesResponse;
exports.unmarshalListSnapshotsResponse = unmarshalListSnapshotsResponse;
exports.unmarshalListUsersResponse = unmarshalListUsersResponse;
exports.unmarshalListVersionsResponse = unmarshalListVersionsResponse;
exports.unmarshalSnapshot = unmarshalSnapshot;
exports.unmarshalUser = unmarshalUser;
exports.unmarshalVolume = unmarshalVolume;
