"use strict";
Object.defineProperty(exports, Symbol.toStringTag, { value: "Module" });
require("../../../client/dist/internal/logger/index.cjs");
const json = require("../../../client/dist/helpers/json.cjs");
const marshalling = require("../../../client/dist/helpers/marshalling.cjs");
require("../../../client/dist/vendor/base64/index.cjs");
const unmarshalFolder = (data) => {
  if (!json.isJSONObject(data)) {
    throw new TypeError(
      `Unmarshalling the type 'Folder' failed as data isn't a dictionary.`
    );
  }
  return {
    createdAt: marshalling.unmarshalDate(data.created_at),
    id: data.id,
    name: data.name,
    path: data.path,
    projectId: data.project_id,
    region: data.region
  };
};
const unmarshalEphemeralProperties = (data) => {
  if (!json.isJSONObject(data)) {
    throw new TypeError(
      `Unmarshalling the type 'EphemeralProperties' failed as data isn't a dictionary.`
    );
  }
  return {
    action: data.action,
    expiresAt: marshalling.unmarshalDate(data.expires_at),
    expiresOnceAccessed: data.expires_once_accessed
  };
};
const unmarshalSecretVersion = (data) => {
  if (!json.isJSONObject(data)) {
    throw new TypeError(
      `Unmarshalling the type 'SecretVersion' failed as data isn't a dictionary.`
    );
  }
  return {
    createdAt: marshalling.unmarshalDate(data.created_at),
    description: data.description,
    ephemeralProperties: data.ephemeral_properties ? unmarshalEphemeralProperties(data.ephemeral_properties) : void 0,
    isLatest: data.is_latest,
    revision: data.revision,
    secretId: data.secret_id,
    status: data.status,
    updatedAt: marshalling.unmarshalDate(data.updated_at)
  };
};
const unmarshalEphemeralPolicy = (data) => {
  if (!json.isJSONObject(data)) {
    throw new TypeError(
      `Unmarshalling the type 'EphemeralPolicy' failed as data isn't a dictionary.`
    );
  }
  return {
    action: data.action,
    expiresOnceAccessed: data.expires_once_accessed,
    timeToLive: data.time_to_live
  };
};
const unmarshalSecret = (data) => {
  if (!json.isJSONObject(data)) {
    throw new TypeError(
      `Unmarshalling the type 'Secret' failed as data isn't a dictionary.`
    );
  }
  return {
    createdAt: marshalling.unmarshalDate(data.created_at),
    description: data.description,
    ephemeralPolicy: data.ephemeral_policy ? unmarshalEphemeralPolicy(data.ephemeral_policy) : void 0,
    id: data.id,
    isManaged: data.is_managed,
    isProtected: data.is_protected,
    name: data.name,
    path: data.path,
    projectId: data.project_id,
    region: data.region,
    status: data.status,
    tags: data.tags,
    type: data.type,
    updatedAt: marshalling.unmarshalDate(data.updated_at),
    versionCount: data.version_count
  };
};
const unmarshalAccessSecretVersionResponse = (data) => {
  if (!json.isJSONObject(data)) {
    throw new TypeError(
      `Unmarshalling the type 'AccessSecretVersionResponse' failed as data isn't a dictionary.`
    );
  }
  return {
    data: data.data,
    dataCrc32: data.data_crc32,
    revision: data.revision,
    secretId: data.secret_id
  };
};
const unmarshalListFoldersResponse = (data) => {
  if (!json.isJSONObject(data)) {
    throw new TypeError(
      `Unmarshalling the type 'ListFoldersResponse' failed as data isn't a dictionary.`
    );
  }
  return {
    folders: marshalling.unmarshalArrayOfObject(data.folders, unmarshalFolder),
    totalCount: data.total_count
  };
};
const unmarshalListSecretVersionsResponse = (data) => {
  if (!json.isJSONObject(data)) {
    throw new TypeError(
      `Unmarshalling the type 'ListSecretVersionsResponse' failed as data isn't a dictionary.`
    );
  }
  return {
    totalCount: data.total_count,
    versions: marshalling.unmarshalArrayOfObject(data.versions, unmarshalSecretVersion)
  };
};
const unmarshalListSecretsResponse = (data) => {
  if (!json.isJSONObject(data)) {
    throw new TypeError(
      `Unmarshalling the type 'ListSecretsResponse' failed as data isn't a dictionary.`
    );
  }
  return {
    secrets: marshalling.unmarshalArrayOfObject(data.secrets, unmarshalSecret),
    totalCount: data.total_count
  };
};
const unmarshalListTagsResponse = (data) => {
  if (!json.isJSONObject(data)) {
    throw new TypeError(
      `Unmarshalling the type 'ListTagsResponse' failed as data isn't a dictionary.`
    );
  }
  return {
    tags: data.tags,
    totalCount: data.total_count
  };
};
const marshalAddSecretOwnerRequest = (request, defaults) => ({
  product: request.product,
  product_name: request.productName
});
const marshalCreateFolderRequest = (request, defaults) => ({
  name: request.name,
  path: request.path,
  project_id: request.projectId ?? defaults.defaultProjectId
});
const marshalEphemeralPolicy = (request, defaults) => ({
  action: request.action,
  expires_once_accessed: request.expiresOnceAccessed,
  time_to_live: request.timeToLive
});
const marshalCreateSecretRequest = (request, defaults) => ({
  description: request.description,
  ephemeral_policy: request.ephemeralPolicy !== void 0 ? marshalEphemeralPolicy(request.ephemeralPolicy) : void 0,
  is_protected: request.isProtected,
  name: request.name,
  path: request.path,
  project_id: request.projectId ?? defaults.defaultProjectId,
  tags: request.tags,
  type: request.type
});
const marshalPasswordGenerationParams = (request, defaults) => ({
  additional_chars: request.additionalChars,
  length: request.length,
  no_digits: request.noDigits,
  no_lowercase_letters: request.noLowercaseLetters,
  no_uppercase_letters: request.noUppercaseLetters
});
const marshalCreateSecretVersionRequest = (request, defaults) => ({
  data: request.data,
  data_crc32: request.dataCrc32,
  description: request.description,
  disable_previous: request.disablePrevious,
  password_generation: request.passwordGeneration !== void 0 ? marshalPasswordGenerationParams(request.passwordGeneration) : void 0
});
const marshalGeneratePasswordRequest = (request, defaults) => ({
  additional_chars: request.additionalChars,
  description: request.description,
  disable_previous: request.disablePrevious,
  length: request.length,
  no_digits: request.noDigits,
  no_lowercase_letters: request.noLowercaseLetters,
  no_uppercase_letters: request.noUppercaseLetters
});
const marshalUpdateSecretRequest = (request, defaults) => ({
  description: request.description,
  ephemeral_policy: request.ephemeralPolicy !== void 0 ? marshalEphemeralPolicy(request.ephemeralPolicy) : void 0,
  name: request.name,
  path: request.path,
  tags: request.tags
});
const marshalEphemeralProperties = (request, defaults) => ({
  action: request.action,
  expires_at: request.expiresAt,
  expires_once_accessed: request.expiresOnceAccessed
});
const marshalUpdateSecretVersionRequest = (request, defaults) => ({
  description: request.description,
  ephemeral_properties: request.ephemeralProperties !== void 0 ? marshalEphemeralProperties(request.ephemeralProperties) : void 0
});
exports.marshalAddSecretOwnerRequest = marshalAddSecretOwnerRequest;
exports.marshalCreateFolderRequest = marshalCreateFolderRequest;
exports.marshalCreateSecretRequest = marshalCreateSecretRequest;
exports.marshalCreateSecretVersionRequest = marshalCreateSecretVersionRequest;
exports.marshalEphemeralPolicy = marshalEphemeralPolicy;
exports.marshalGeneratePasswordRequest = marshalGeneratePasswordRequest;
exports.marshalUpdateSecretRequest = marshalUpdateSecretRequest;
exports.marshalUpdateSecretVersionRequest = marshalUpdateSecretVersionRequest;
exports.unmarshalAccessSecretVersionResponse = unmarshalAccessSecretVersionResponse;
exports.unmarshalEphemeralPolicy = unmarshalEphemeralPolicy;
exports.unmarshalFolder = unmarshalFolder;
exports.unmarshalListFoldersResponse = unmarshalListFoldersResponse;
exports.unmarshalListSecretVersionsResponse = unmarshalListSecretVersionsResponse;
exports.unmarshalListSecretsResponse = unmarshalListSecretsResponse;
exports.unmarshalListTagsResponse = unmarshalListTagsResponse;
exports.unmarshalSecret = unmarshalSecret;
exports.unmarshalSecretVersion = unmarshalSecretVersion;
