import { API as ParentAPI } from '@scaleway/sdk-client';
import type { Zone } from '@scaleway/sdk-client';
import type { CreatePrivateNetworkRequest, DeletePrivateNetworkRequest, GetPrivateNetworkRequest, ListPrivateNetworksRequest, ListPrivateNetworksResponse, PrivateNetwork, UpdatePrivateNetworkRequest } from './types.gen';
/**
 * VPC API.
 *
 * This API allows you to manage your Virtual Private Clouds (VPCs) and Private
 * Networks.
 */
export declare class API extends ParentAPI {
    /** Lists the available zones of the API. */
    static readonly LOCALITIES: Zone[];
    protected pageOfListPrivateNetworks: (request?: Readonly<ListPrivateNetworksRequest>) => Promise<ListPrivateNetworksResponse>;
    /**
     * List Private Networks. List existing Private Networks in a specified
     * Availability Zone. By default, the Private Networks returned in the list
     * are ordered by creation date in ascending order, though this can be
     * modified via the order_by field.
     *
     * @param request - The request {@link ListPrivateNetworksRequest}
     * @returns A Promise of ListPrivateNetworksResponse
     */
    listPrivateNetworks: (request?: Readonly<ListPrivateNetworksRequest>) => Promise<ListPrivateNetworksResponse> & {
        all: () => Promise<PrivateNetwork[]>;
        [Symbol.asyncIterator]: () => AsyncGenerator<PrivateNetwork[], void, void>;
    };
    /**
     * Create a Private Network. Create a new Private Network. Once created, you
     * can attach Scaleway resources in the same Availability Zone.
     *
     * @param request - The request {@link CreatePrivateNetworkRequest}
     * @returns A Promise of PrivateNetwork
     */
    createPrivateNetwork: (request?: Readonly<CreatePrivateNetworkRequest>) => Promise<PrivateNetwork>;
    /**
     * Get a Private Network. Retrieve information about an existing Private
     * Network, specified by its Private Network ID. Its full details are returned
     * in the response object.
     *
     * @param request - The request {@link GetPrivateNetworkRequest}
     * @returns A Promise of PrivateNetwork
     */
    getPrivateNetwork: (request: Readonly<GetPrivateNetworkRequest>) => Promise<PrivateNetwork>;
    /**
     * Update Private Network. Update parameters (such as name or tags) of an
     * existing Private Network, specified by its Private Network ID.
     *
     * @param request - The request {@link UpdatePrivateNetworkRequest}
     * @returns A Promise of PrivateNetwork
     */
    updatePrivateNetwork: (request: Readonly<UpdatePrivateNetworkRequest>) => Promise<PrivateNetwork>;
    /**
     * Delete a Private Network. Delete an existing Private Network. Note that you
     * must first detach all resources from the network, in order to delete it.
     *
     * @param request - The request {@link DeletePrivateNetworkRequest}
     */
    deletePrivateNetwork: (request: Readonly<DeletePrivateNetworkRequest>) => Promise<void>;
}
