import "../../../client/dist/internal/logger/index.js";
import { waitForResource } from "../../../client/dist/internal/async/interval-retrier.js";
import { API as API$1 } from "../../../client/dist/scw/api.js";
import { validatePathParam, urlParams } from "../../../client/dist/helpers/marshalling.js";
import "../../../client/dist/vendor/base64/index.js";
import { enrichForPagination } from "../../../client/dist/scw/fetch/resource-paginator.js";
import { DOMAIN_TRANSIENT_STATUSES, HOSTING_TRANSIENT_STATUSES } from "./content.gen.js";
import { unmarshalListControlPanelsResponse, marshalDatabaseApiCreateDatabaseRequest, unmarshalDatabase, unmarshalListDatabasesResponse, marshalDatabaseApiCreateDatabaseUserRequest, unmarshalDatabaseUser, unmarshalListDatabaseUsersResponse, marshalDatabaseApiChangeDatabaseUserPasswordRequest, marshalDatabaseApiAssignDatabaseUserRequest, marshalDatabaseApiUnassignDatabaseUserRequest, unmarshalDnsRecords, marshalDnsApiCheckUserOwnsDomainRequest, unmarshalCheckUserOwnsDomainResponse, marshalDnsApiSyncDomainDnsRecordsRequest, unmarshalSearchDomainsResponse, unmarshalDomain, unmarshalListOffersResponse, marshalHostingApiCreateHostingRequest, unmarshalHosting, unmarshalListHostingsResponse, marshalHostingApiUpdateHostingRequest, unmarshalSession, unmarshalResetHostingPasswordResponse, unmarshalResourceSummary, marshalFtpAccountApiCreateFtpAccountRequest, unmarshalFtpAccount, unmarshalListFtpAccountsResponse, marshalFtpAccountApiChangeFtpAccountPasswordRequest, marshalMailAccountApiCreateMailAccountRequest, unmarshalMailAccount, unmarshalListMailAccountsResponse, marshalMailAccountApiRemoveMailAccountRequest, marshalMailAccountApiChangeMailAccountPasswordRequest, unmarshalListWebsitesResponse } from "./marshalling.gen.js";
const jsonContentHeaders = {
  "Content-Type": "application/json; charset=utf-8"
};
class ControlPanelAPI extends API$1 {
  /** Lists the available regions of the API. */
  static LOCALITIES = [
    "fr-par",
    "nl-ams",
    "pl-waw"
  ];
  pageOfListControlPanels = (request = {}) => this.client.fetch(
    {
      method: "GET",
      path: `/webhosting/v1/regions/${validatePathParam("region", request.region ?? this.client.settings.defaultRegion)}/control-panels`,
      urlParams: urlParams(
        ["page", request.page],
        [
          "page_size",
          request.pageSize ?? this.client.settings.defaultPageSize
        ]
      )
    },
    unmarshalListControlPanelsResponse
  );
  /**
   * "List the control panels type: cpanel or plesk.".
   *
   * @param request - The request {@link ControlPanelApiListControlPanelsRequest}
   * @returns A Promise of ListControlPanelsResponse
   */
  listControlPanels = (request = {}) => enrichForPagination("controlPanels", this.pageOfListControlPanels, request);
}
class DatabaseAPI extends API$1 {
  /** Lists the available regions of the API. */
  static LOCALITIES = [
    "fr-par",
    "nl-ams",
    "pl-waw"
  ];
  /**
   * "Create a new database within your hosting plan".
   *
   * @param request - The request {@link DatabaseApiCreateDatabaseRequest}
   * @returns A Promise of Database
   */
  createDatabase = (request) => this.client.fetch(
    {
      body: JSON.stringify(
        marshalDatabaseApiCreateDatabaseRequest(
          request,
          this.client.settings
        )
      ),
      headers: jsonContentHeaders,
      method: "POST",
      path: `/webhosting/v1/regions/${validatePathParam("region", request.region ?? this.client.settings.defaultRegion)}/hostings/${validatePathParam("hostingId", request.hostingId)}/databases`
    },
    unmarshalDatabase
  );
  pageOfListDatabases = (request) => this.client.fetch(
    {
      method: "GET",
      path: `/webhosting/v1/regions/${validatePathParam("region", request.region ?? this.client.settings.defaultRegion)}/hostings/${validatePathParam("hostingId", request.hostingId)}/databases`,
      urlParams: urlParams(
        ["order_by", request.orderBy],
        ["page", request.page],
        [
          "page_size",
          request.pageSize ?? this.client.settings.defaultPageSize
        ]
      )
    },
    unmarshalListDatabasesResponse
  );
  /**
   * "List all databases within your hosting plan".
   *
   * @param request - The request {@link DatabaseApiListDatabasesRequest}
   * @returns A Promise of ListDatabasesResponse
   */
  listDatabases = (request) => enrichForPagination("databases", this.pageOfListDatabases, request);
  /**
   * "Get details of a database within your hosting plan".
   *
   * @param request - The request {@link DatabaseApiGetDatabaseRequest}
   * @returns A Promise of Database
   */
  getDatabase = (request) => this.client.fetch(
    {
      method: "GET",
      path: `/webhosting/v1/regions/${validatePathParam("region", request.region ?? this.client.settings.defaultRegion)}/hostings/${validatePathParam("hostingId", request.hostingId)}/databases/${validatePathParam("databaseName", request.databaseName)}`
    },
    unmarshalDatabase
  );
  /**
   * "Delete a database within your hosting plan".
   *
   * @param request - The request {@link DatabaseApiDeleteDatabaseRequest}
   * @returns A Promise of Database
   */
  deleteDatabase = (request) => this.client.fetch(
    {
      method: "DELETE",
      path: `/webhosting/v1/regions/${validatePathParam("region", request.region ?? this.client.settings.defaultRegion)}/hostings/${validatePathParam("hostingId", request.hostingId)}/databases/${validatePathParam("databaseName", request.databaseName)}`
    },
    unmarshalDatabase
  );
  /**
   * "Create a new database user".
   *
   * @param request - The request {@link DatabaseApiCreateDatabaseUserRequest}
   * @returns A Promise of DatabaseUser
   */
  createDatabaseUser = (request) => this.client.fetch(
    {
      body: JSON.stringify(
        marshalDatabaseApiCreateDatabaseUserRequest(
          request,
          this.client.settings
        )
      ),
      headers: jsonContentHeaders,
      method: "POST",
      path: `/webhosting/v1/regions/${validatePathParam("region", request.region ?? this.client.settings.defaultRegion)}/hostings/${validatePathParam("hostingId", request.hostingId)}/databases-users`
    },
    unmarshalDatabaseUser
  );
  pageOfListDatabaseUsers = (request) => this.client.fetch(
    {
      method: "GET",
      path: `/webhosting/v1/regions/${validatePathParam("region", request.region ?? this.client.settings.defaultRegion)}/hostings/${validatePathParam("hostingId", request.hostingId)}/database-users`,
      urlParams: urlParams(
        ["order_by", request.orderBy],
        ["page", request.page],
        [
          "page_size",
          request.pageSize ?? this.client.settings.defaultPageSize
        ]
      )
    },
    unmarshalListDatabaseUsersResponse
  );
  /**
   * "List all database users".
   *
   * @param request - The request {@link DatabaseApiListDatabaseUsersRequest}
   * @returns A Promise of ListDatabaseUsersResponse
   */
  listDatabaseUsers = (request) => enrichForPagination("users", this.pageOfListDatabaseUsers, request);
  /**
   * "Get details of a database user".
   *
   * @param request - The request {@link DatabaseApiGetDatabaseUserRequest}
   * @returns A Promise of DatabaseUser
   */
  getDatabaseUser = (request) => this.client.fetch(
    {
      method: "GET",
      path: `/webhosting/v1/regions/${validatePathParam("region", request.region ?? this.client.settings.defaultRegion)}/hostings/${validatePathParam("hostingId", request.hostingId)}/databases-users/${validatePathParam("username", request.username)}`
    },
    unmarshalDatabaseUser
  );
  /**
   * "Delete a database user".
   *
   * @param request - The request {@link DatabaseApiDeleteDatabaseUserRequest}
   * @returns A Promise of DatabaseUser
   */
  deleteDatabaseUser = (request) => this.client.fetch(
    {
      method: "DELETE",
      path: `/webhosting/v1/regions/${validatePathParam("region", request.region ?? this.client.settings.defaultRegion)}/hostings/${validatePathParam("hostingId", request.hostingId)}/database-users/${validatePathParam("username", request.username)}`
    },
    unmarshalDatabaseUser
  );
  /**
   * "Change the password of a database user".
   *
   * @param request - The request {@link DatabaseApiChangeDatabaseUserPasswordRequest}
   * @returns A Promise of DatabaseUser
   */
  changeDatabaseUserPassword = (request) => this.client.fetch(
    {
      body: JSON.stringify(
        marshalDatabaseApiChangeDatabaseUserPasswordRequest(
          request,
          this.client.settings
        )
      ),
      headers: jsonContentHeaders,
      method: "POST",
      path: `/webhosting/v1/regions/${validatePathParam("region", request.region ?? this.client.settings.defaultRegion)}/hostings/${validatePathParam("hostingId", request.hostingId)}/databases-users/${validatePathParam("username", request.username)}/change-password`
    },
    unmarshalDatabaseUser
  );
  /**
   * "Assign a database user to a database".
   *
   * @param request - The request {@link DatabaseApiAssignDatabaseUserRequest}
   * @returns A Promise of DatabaseUser
   */
  assignDatabaseUser = (request) => this.client.fetch(
    {
      body: JSON.stringify(
        marshalDatabaseApiAssignDatabaseUserRequest(
          request,
          this.client.settings
        )
      ),
      headers: jsonContentHeaders,
      method: "POST",
      path: `/webhosting/v1/regions/${validatePathParam("region", request.region ?? this.client.settings.defaultRegion)}/hostings/${validatePathParam("hostingId", request.hostingId)}/databases/${validatePathParam("databaseName", request.databaseName)}/assign-user`
    },
    unmarshalDatabaseUser
  );
  /**
   * "Unassign a database user from a database".
   *
   * @param request - The request {@link DatabaseApiUnassignDatabaseUserRequest}
   * @returns A Promise of DatabaseUser
   */
  unassignDatabaseUser = (request) => this.client.fetch(
    {
      body: JSON.stringify(
        marshalDatabaseApiUnassignDatabaseUserRequest(
          request,
          this.client.settings
        )
      ),
      headers: jsonContentHeaders,
      method: "POST",
      path: `/webhosting/v1/regions/${validatePathParam("region", request.region ?? this.client.settings.defaultRegion)}/hostings/${validatePathParam("hostingId", request.hostingId)}/databases/${validatePathParam("databaseName", request.databaseName)}/unassign-user`
    },
    unmarshalDatabaseUser
  );
}
class DnsAPI extends API$1 {
  /** Lists the available regions of the API. */
  static LOCALITIES = [
    "fr-par",
    "nl-ams",
    "pl-waw"
  ];
  /**
   * Get DNS records. Get the set of DNS records of a specified domain associated with a Web Hosting plan's domain.
   *
   * @param request - The request {@link DnsApiGetDomainDnsRecordsRequest}
   * @returns A Promise of DnsRecords
   */
  getDomainDnsRecords = (request) => this.client.fetch(
    {
      method: "GET",
      path: `/webhosting/v1/regions/${validatePathParam("region", request.region ?? this.client.settings.defaultRegion)}/domains/${validatePathParam("domain", request.domain)}/dns-records`
    },
    unmarshalDnsRecords
  );
  /**
   * Check whether you own this domain or not.. Check whether you own this domain or not.
   *
   * @param request - The request {@link DnsApiCheckUserOwnsDomainRequest}
   * @returns A Promise of CheckUserOwnsDomainResponse
   */
  checkUserOwnsDomain = (request) => this.client.fetch(
    {
      body: JSON.stringify(
        marshalDnsApiCheckUserOwnsDomainRequest(
          request,
          this.client.settings
        )
      ),
      headers: jsonContentHeaders,
      method: "POST",
      path: `/webhosting/v1/regions/${validatePathParam("region", request.region ?? this.client.settings.defaultRegion)}/domains/${validatePathParam("domain", request.domain)}/check-ownership`
    },
    unmarshalCheckUserOwnsDomainResponse
  );
  /**
   * Synchronize your DNS records on the Elements Console and on cPanel.. Synchronize your DNS records on the Elements Console and on cPanel.
   *
   * @param request - The request {@link DnsApiSyncDomainDnsRecordsRequest}
   * @returns A Promise of DnsRecords
   */
  syncDomainDnsRecords = (request) => this.client.fetch(
    {
      body: JSON.stringify(
        marshalDnsApiSyncDomainDnsRecordsRequest(
          request,
          this.client.settings
        )
      ),
      headers: jsonContentHeaders,
      method: "POST",
      path: `/webhosting/v1/regions/${validatePathParam("region", request.region ?? this.client.settings.defaultRegion)}/domains/${validatePathParam("domain", request.domain)}/sync-domain-dns-records`
    },
    unmarshalDnsRecords
  );
  /**
   * Search for available domains based on domain name.. Search for available domains based on domain name.
   *
   * @param request - The request {@link DnsApiSearchDomainsRequest}
   * @returns A Promise of SearchDomainsResponse
   */
  searchDomains = (request) => this.client.fetch(
    {
      method: "GET",
      path: `/webhosting/v1/regions/${validatePathParam("region", request.region ?? this.client.settings.defaultRegion)}/search-domains`,
      urlParams: urlParams(
        ["domain_name", request.domainName],
        [
          "project_id",
          request.projectId ?? this.client.settings.defaultProjectId
        ]
      )
    },
    unmarshalSearchDomainsResponse
  );
  /**
   * Retrieve detailed information about a specific domain, including its status, DNS configuration, and ownership.. Retrieve detailed information about a specific domain, including its status, DNS configuration, and ownership.
   *
   * @param request - The request {@link DnsApiGetDomainRequest}
   * @returns A Promise of Domain
   */
  getDomain = (request) => this.client.fetch(
    {
      method: "GET",
      path: `/webhosting/v1/regions/${validatePathParam("region", request.region ?? this.client.settings.defaultRegion)}/domains/${validatePathParam("domainName", request.domainName)}`,
      urlParams: urlParams([
        "project_id",
        request.projectId ?? this.client.settings.defaultProjectId
      ])
    },
    unmarshalDomain
  );
  /**
   * Waits for {@link Domain} to be in a final state.
   *
   * @param request - The request {@link DnsApiGetDomainRequest}
   * @param options - The waiting options
   * @returns A Promise of Domain
   */
  waitForDomain = (request, options) => waitForResource(
    options?.stop ?? ((res) => Promise.resolve(
      !DOMAIN_TRANSIENT_STATUSES.includes(res.status)
    )),
    this.getDomain,
    request,
    options
  );
}
class OfferAPI extends API$1 {
  /** Lists the available regions of the API. */
  static LOCALITIES = [
    "fr-par",
    "nl-ams",
    "pl-waw"
  ];
  pageOfListOffers = (request = {}) => this.client.fetch(
    {
      method: "GET",
      path: `/webhosting/v1/regions/${validatePathParam("region", request.region ?? this.client.settings.defaultRegion)}/offers`,
      urlParams: urlParams(
        ["control_panels", request.controlPanels],
        ["hosting_id", request.hostingId],
        ["order_by", request.orderBy],
        ["page", request.page],
        [
          "page_size",
          request.pageSize ?? this.client.settings.defaultPageSize
        ]
      )
    },
    unmarshalListOffersResponse
  );
  /**
   * List all available hosting offers along with their specific options.. List all available hosting offers along with their specific options.
   *
   * @param request - The request {@link OfferApiListOffersRequest}
   * @returns A Promise of ListOffersResponse
   */
  listOffers = (request = {}) => enrichForPagination("offers", this.pageOfListOffers, request);
}
class HostingAPI extends API$1 {
  /** Lists the available regions of the API. */
  static LOCALITIES = [
    "fr-par",
    "nl-ams",
    "pl-waw"
  ];
  /**
   * Order a Web Hosting plan. Order a Web Hosting plan, specifying the offer type required via the `offer_id` parameter.
   *
   * @param request - The request {@link HostingApiCreateHostingRequest}
   * @returns A Promise of Hosting
   */
  createHosting = (request) => this.client.fetch(
    {
      body: JSON.stringify(
        marshalHostingApiCreateHostingRequest(request, this.client.settings)
      ),
      headers: jsonContentHeaders,
      method: "POST",
      path: `/webhosting/v1/regions/${validatePathParam("region", request.region ?? this.client.settings.defaultRegion)}/hostings`
    },
    unmarshalHosting
  );
  pageOfListHostings = (request = {}) => this.client.fetch(
    {
      method: "GET",
      path: `/webhosting/v1/regions/${validatePathParam("region", request.region ?? this.client.settings.defaultRegion)}/hostings`,
      urlParams: urlParams(
        ["control_panels", request.controlPanels],
        ["domain", request.domain],
        ["order_by", request.orderBy],
        ["organization_id", request.organizationId],
        ["page", request.page],
        [
          "page_size",
          request.pageSize ?? this.client.settings.defaultPageSize
        ],
        ["project_id", request.projectId],
        ["statuses", request.statuses],
        ["tags", request.tags]
      )
    },
    unmarshalListHostingsResponse
  );
  /**
   * List all Web Hosting plans. List all of your existing Web Hosting plans. Various filters are available to limit the results, including filtering by domain, status, tag and Project ID.
   *
   * @param request - The request {@link HostingApiListHostingsRequest}
   * @returns A Promise of ListHostingsResponse
   */
  listHostings = (request = {}) => enrichForPagination("hostings", this.pageOfListHostings, request);
  /**
   * Get a Web Hosting plan. Get the details of one of your existing Web Hosting plans, specified by its `hosting_id`.
   *
   * @param request - The request {@link HostingApiGetHostingRequest}
   * @returns A Promise of Hosting
   */
  getHosting = (request) => this.client.fetch(
    {
      method: "GET",
      path: `/webhosting/v1/regions/${validatePathParam("region", request.region ?? this.client.settings.defaultRegion)}/hostings/${validatePathParam("hostingId", request.hostingId)}`
    },
    unmarshalHosting
  );
  /**
   * Waits for {@link Hosting} to be in a final state.
   *
   * @param request - The request {@link HostingApiGetHostingRequest}
   * @param options - The waiting options
   * @returns A Promise of Hosting
   */
  waitForHosting = (request, options) => waitForResource(
    options?.stop ?? ((res) => Promise.resolve(
      !HOSTING_TRANSIENT_STATUSES.includes(res.status)
    )),
    this.getHosting,
    request,
    options
  );
  /**
   * Update a Web Hosting plan. Update the details of one of your existing Web Hosting plans, specified by its `hosting_id`. You can update parameters including the contact email address, tags, options and offer.
   *
   * @param request - The request {@link HostingApiUpdateHostingRequest}
   * @returns A Promise of Hosting
   */
  updateHosting = (request) => this.client.fetch(
    {
      body: JSON.stringify(
        marshalHostingApiUpdateHostingRequest(request, this.client.settings)
      ),
      headers: jsonContentHeaders,
      method: "PATCH",
      path: `/webhosting/v1/regions/${validatePathParam("region", request.region ?? this.client.settings.defaultRegion)}/hostings/${validatePathParam("hostingId", request.hostingId)}`
    },
    unmarshalHosting
  );
  /**
   * Delete a Web Hosting plan. Delete a Web Hosting plan, specified by its `hosting_id`. Note that deletion is not immediate: it will take place at the end of the calendar month, after which time your Web Hosting plan and all its data (files and emails) will be irreversibly lost.
   *
   * @param request - The request {@link HostingApiDeleteHostingRequest}
   * @returns A Promise of Hosting
   */
  deleteHosting = (request) => this.client.fetch(
    {
      method: "DELETE",
      path: `/webhosting/v1/regions/${validatePathParam("region", request.region ?? this.client.settings.defaultRegion)}/hostings/${validatePathParam("hostingId", request.hostingId)}`
    },
    unmarshalHosting
  );
  /**
   * Create a user session.
   *
   * @param request - The request {@link HostingApiCreateSessionRequest}
   * @returns A Promise of Session
   */
  createSession = (request) => this.client.fetch(
    {
      body: "{}",
      headers: jsonContentHeaders,
      method: "POST",
      path: `/webhosting/v1/regions/${validatePathParam("region", request.region ?? this.client.settings.defaultRegion)}/hostings/${validatePathParam("hostingId", request.hostingId)}/sessions`
    },
    unmarshalSession
  );
  /**
   * Reset a Web Hosting plan password.
   *
   * @param request - The request {@link HostingApiResetHostingPasswordRequest}
   * @returns A Promise of ResetHostingPasswordResponse
   */
  resetHostingPassword = (request) => this.client.fetch(
    {
      body: "{}",
      headers: jsonContentHeaders,
      method: "POST",
      path: `/webhosting/v1/regions/${validatePathParam("region", request.region ?? this.client.settings.defaultRegion)}/hostings/${validatePathParam("hostingId", request.hostingId)}/reset-password`
    },
    unmarshalResetHostingPasswordResponse
  );
  /**
   * Get the total counts of websites, databases, email accounts, and FTP accounts of a Web Hosting plan.
   *
   * @param request - The request {@link HostingApiGetResourceSummaryRequest}
   * @returns A Promise of ResourceSummary
   */
  getResourceSummary = (request) => this.client.fetch(
    {
      method: "GET",
      path: `/webhosting/v1/regions/${validatePathParam("region", request.region ?? this.client.settings.defaultRegion)}/hostings/${validatePathParam("hostingId", request.hostingId)}/resource-summary`
    },
    unmarshalResourceSummary
  );
}
class FtpAccountAPI extends API$1 {
  /** Lists the available regions of the API. */
  static LOCALITIES = [
    "fr-par",
    "nl-ams",
    "pl-waw"
  ];
  /**
   * Create a new FTP account within your hosting plan.. Create a new FTP account within your hosting plan.
   *
   * @param request - The request {@link FtpAccountApiCreateFtpAccountRequest}
   * @returns A Promise of FtpAccount
   */
  createFtpAccount = (request) => this.client.fetch(
    {
      body: JSON.stringify(
        marshalFtpAccountApiCreateFtpAccountRequest(
          request,
          this.client.settings
        )
      ),
      headers: jsonContentHeaders,
      method: "POST",
      path: `/webhosting/v1/regions/${validatePathParam("region", request.region ?? this.client.settings.defaultRegion)}/hostings/${validatePathParam("hostingId", request.hostingId)}/ftp-accounts`
    },
    unmarshalFtpAccount
  );
  pageOfListFtpAccounts = (request) => this.client.fetch(
    {
      method: "GET",
      path: `/webhosting/v1/regions/${validatePathParam("region", request.region ?? this.client.settings.defaultRegion)}/hostings/${validatePathParam("hostingId", request.hostingId)}/ftp-accounts`,
      urlParams: urlParams(
        ["domain", request.domain],
        ["order_by", request.orderBy],
        ["page", request.page],
        [
          "page_size",
          request.pageSize ?? this.client.settings.defaultPageSize
        ]
      )
    },
    unmarshalListFtpAccountsResponse
  );
  /**
   * List all FTP accounts within your hosting plan.. List all FTP accounts within your hosting plan.
   *
   * @param request - The request {@link FtpAccountApiListFtpAccountsRequest}
   * @returns A Promise of ListFtpAccountsResponse
   */
  listFtpAccounts = (request) => enrichForPagination("ftpAccounts", this.pageOfListFtpAccounts, request);
  /**
   * Delete a specific FTP account within your hosting plan.. Delete a specific FTP account within your hosting plan.
   *
   * @param request - The request {@link FtpAccountApiRemoveFtpAccountRequest}
   * @returns A Promise of FtpAccount
   */
  removeFtpAccount = (request) => this.client.fetch(
    {
      method: "DELETE",
      path: `/webhosting/v1/regions/${validatePathParam("region", request.region ?? this.client.settings.defaultRegion)}/hostings/${validatePathParam("hostingId", request.hostingId)}/ftp-accounts/${validatePathParam("username", request.username)}`
    },
    unmarshalFtpAccount
  );
  changeFtpAccountPassword = (request) => this.client.fetch(
    {
      body: JSON.stringify(
        marshalFtpAccountApiChangeFtpAccountPasswordRequest(
          request,
          this.client.settings
        )
      ),
      headers: jsonContentHeaders,
      method: "POST",
      path: `/webhosting/v1/regions/${validatePathParam("region", request.region ?? this.client.settings.defaultRegion)}/hostings/${validatePathParam("hostingId", request.hostingId)}/ftp-accounts/${validatePathParam("username", request.username)}/change-password`
    },
    unmarshalFtpAccount
  );
}
class MailAccountAPI extends API$1 {
  /** Lists the available regions of the API. */
  static LOCALITIES = [
    "fr-par",
    "nl-ams",
    "pl-waw"
  ];
  /**
   * Create a new mail account within your hosting plan.. Create a new mail account within your hosting plan.
   *
   * @param request - The request {@link MailAccountApiCreateMailAccountRequest}
   * @returns A Promise of MailAccount
   */
  createMailAccount = (request) => this.client.fetch(
    {
      body: JSON.stringify(
        marshalMailAccountApiCreateMailAccountRequest(
          request,
          this.client.settings
        )
      ),
      headers: jsonContentHeaders,
      method: "POST",
      path: `/webhosting/v1/regions/${validatePathParam("region", request.region ?? this.client.settings.defaultRegion)}/hostings/${validatePathParam("hostingId", request.hostingId)}/mail-accounts`
    },
    unmarshalMailAccount
  );
  pageOfListMailAccounts = (request) => this.client.fetch(
    {
      method: "GET",
      path: `/webhosting/v1/regions/${validatePathParam("region", request.region ?? this.client.settings.defaultRegion)}/hostings/${validatePathParam("hostingId", request.hostingId)}/mail-accounts`,
      urlParams: urlParams(
        ["domain", request.domain],
        ["order_by", request.orderBy],
        ["page", request.page],
        [
          "page_size",
          request.pageSize ?? this.client.settings.defaultPageSize
        ]
      )
    },
    unmarshalListMailAccountsResponse
  );
  /**
   * List all mail accounts within your hosting plan.. List all mail accounts within your hosting plan.
   *
   * @param request - The request {@link MailAccountApiListMailAccountsRequest}
   * @returns A Promise of ListMailAccountsResponse
   */
  listMailAccounts = (request) => enrichForPagination("mailAccounts", this.pageOfListMailAccounts, request);
  /**
   * Delete a mail account within your hosting plan.. Delete a mail account within your hosting plan.
   *
   * @param request - The request {@link MailAccountApiRemoveMailAccountRequest}
   * @returns A Promise of MailAccount
   */
  removeMailAccount = (request) => this.client.fetch(
    {
      body: JSON.stringify(
        marshalMailAccountApiRemoveMailAccountRequest(
          request,
          this.client.settings
        )
      ),
      headers: jsonContentHeaders,
      method: "POST",
      path: `/webhosting/v1/regions/${validatePathParam("region", request.region ?? this.client.settings.defaultRegion)}/hostings/${validatePathParam("hostingId", request.hostingId)}/remove-mail-account`
    },
    unmarshalMailAccount
  );
  /**
   * Update the password of a mail account within your hosting plan.. Update the password of a mail account within your hosting plan.
   *
   * @param request - The request {@link MailAccountApiChangeMailAccountPasswordRequest}
   * @returns A Promise of MailAccount
   */
  changeMailAccountPassword = (request) => this.client.fetch(
    {
      body: JSON.stringify(
        marshalMailAccountApiChangeMailAccountPasswordRequest(
          request,
          this.client.settings
        )
      ),
      headers: jsonContentHeaders,
      method: "POST",
      path: `/webhosting/v1/regions/${validatePathParam("region", request.region ?? this.client.settings.defaultRegion)}/hostings/${validatePathParam("hostingId", request.hostingId)}/change-mail-password`
    },
    unmarshalMailAccount
  );
}
class WebsiteAPI extends API$1 {
  /** Lists the available regions of the API. */
  static LOCALITIES = [
    "fr-par",
    "nl-ams",
    "pl-waw"
  ];
  pageOfListWebsites = (request) => this.client.fetch(
    {
      method: "GET",
      path: `/webhosting/v1/regions/${validatePathParam("region", request.region ?? this.client.settings.defaultRegion)}/hostings/${validatePathParam("hostingId", request.hostingId)}/websites`,
      urlParams: urlParams(
        ["order_by", request.orderBy],
        ["page", request.page],
        [
          "page_size",
          request.pageSize ?? this.client.settings.defaultPageSize
        ]
      )
    },
    unmarshalListWebsitesResponse
  );
  /**
   * List all websites for a specific hosting.. List all websites for a specific hosting.
   *
   * @param request - The request {@link WebsiteApiListWebsitesRequest}
   * @returns A Promise of ListWebsitesResponse
   */
  listWebsites = (request) => enrichForPagination("websites", this.pageOfListWebsites, request);
}
export {
  ControlPanelAPI,
  DatabaseAPI,
  DnsAPI,
  FtpAccountAPI,
  HostingAPI,
  MailAccountAPI,
  OfferAPI,
  WebsiteAPI
};
